*** Bin all of the earnings variables ***;

*** OPTIONS ***;
options spool mlogic mprint symbolgen fullstimer msglevel=i ps=200 ls=200 nocenter obs=max;

libname dot ".";

libname interwrk "../sastemp";

%put SASUSER path=%sysfunc(pathname(sasuser));

***%let var=labor;
***%let cond=>0;
***%let cnt=10;
***%let ybeg=1998;
***%let yend=2019;

%macro loop;

%do yr = &ybeg %to &yend;

   title "****** Processing Year=&yr *******";

   proc sort data=interwrk.&var(keep=personid male yob &var.&yr where=(&var.&yr&cond)) out=temp1;
      by male yob &var.&yr;
   run;
   
   *** Check to make sure there at least X obs per male yob cell ***;
   
   proc freq data=temp1 noprint;
      tables male*yob /out=cntcheck;
   run;
   
   data ct2;
      set cntcheck;
   
      length emessage $11;
      if COUNT<&cnt then do;
         emessage="Count LT &cnt";
         output;
      end;
   run;
      
   proc contents data=ct2;
   proc print data=ct2;
   run;
   
   *** Create the bins ***;
   
   data temp2(drop=counter);
      set temp1;
         by male yob;
   
      retain bin counter vval;
   
      if _N_=1 then bin=0;
   
      if first.yob then do;
         bin=bin+1;
         counter=0;
         vval=&var.&yr;
      end;
   
      counter=counter+1;

      if vval~=&var.&yr and counter>&cnt then do;
         counter=1;
         bin=bin+1;
         vval=&var.&yr;
      end;
   run;
   
   proc contents data=temp2;
   proc print data=temp2(obs=100);
   run;
   
   *** Get the number of records per bin ***;
         
   proc summary data=temp2 nway;
      class male yob bin;
      output out=temp3(drop=_TYPE_ _FREQ_) n(&var.&yr)=bcnt;
   run;

   proc contents data=temp3;
   proc means data=temp3(where=(bcnt<&cnt));
      var bcnt;
   run;
   
   data temp4(drop=bcnt);
     merge temp2 temp3;
        by male yob bin;
   
     if bcnt<&cnt then bin=bin-1;
   run;
   
   proc contents data=temp4;
   proc print data=temp4(obs=100);
   run;
   
   *** Create bin average earnings ***;
   
   proc summary data=temp4 nway;
      class male yob bin;
      output out=temp5(drop=_TYPE_ _FREQ_) n(&var.&yr)=bcnt mean(&var.&yr)=bmn;
   run;
   
   proc contents data=temp5;
   proc means data=temp5;
      var bcnt;
   run;
   
   data temp6;
     merge temp4 temp5;
        by male yob bin;
   
     ediff=bmn-&var.&yr;
     if &var.&yr~=0 then ediffp=(bmn-&var.&yr)/&var.&yr;
   run;
   
   proc contents data=temp6;
   proc means data=temp6 n mean min p1 p5 p25 median p75 p95 p99 max;
      var ediff ediffp;
   run;
   proc print data=temp6(obs=100);
   run;
   
   *** Output final Year file ***;
   
   proc sort data=temp6(keep=personid bmn) out=&var.&yr(rename=(bmn=&var.&yr)); 
      by personid;
   run;
   
   proc contents data=&var.&yr;
   proc print data=&var.&yr(obs=100);
   run;
%end;
%mend;
%loop;

%macro kmrg;
   %do yr = &ybeg %to &yend;
      &var.&yr
   %end;
%mend;

data interwrk.&var._bin(sortedby=personid);
   merge %kmrg;
      by personid;
run;

proc contents data=interwrk.&var._bin;
proc means data=interwrk.&var._bin;
proc print data=interwrk.&var._bin(obs=100);
run;
