// !!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
// This program generates the time series of concetration and inequality
// This version Jan 25, 2022
// Serdar Ozkan and Sergio Salgado
// !!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!

clear all
set more off
set type double
 
// You should change the below directory. 

global maindir =""

// Do not make change from here on. Contact Ozkan/Salgado if changes are needed. 
do "$maindir/do/0_Initialize.do"

// Create folder for output and log-file
global outfolder="17 Mar 2022 Inequality"
capture log close

// Cd to the output file, create the program for moments, and load base sample.
cd "$maindir${sep}out${sep}$outfolder"
do "$maindir${sep}do${sep}myprogs.do"		

// Defines the number of points in the Kernel Density Estimator
global kpoints =  400

// Loop over the years
timer clear 1
timer on 1

foreach yr of numlist $yrlist{
        if `yr' == $yrfirst{
                use temporal_`yr'.dta, clear
                save "$maindir${sep}dta${sep}temporal.dta", replace
                erase temporal_`yr'.dta
        }
        else{
                use "$maindir${sep}dta${sep}temporal.dta", clear
                append using temporal_`yr'.dta
                save "$maindir${sep}dta${sep}temporal.dta", replace
                erase temporal_`yr'.dta
        }
}

order country year gender age
sort country gender age year
export delimited using "$maindir${sep}out${sep}$outfolder${sep}autocorr.csv", replace
erase "$maindir${sep}dta${sep}temporal.dta"
// END of section for autocovariance.


// Collect data across years 
clear
foreach vari in logearn researn {

foreach yr of numlist $yrlist{

	use "$maindir${sep}out${sep}$outfolder/S_L_`vari'_`yr'.dta", clear
	merge 1:1 year using "$maindir${sep}out${sep}$outfolder/PC_L_`vari'_`yr'.dta", ///
		nogenerate
	erase "$maindir${sep}out${sep}$outfolder/S_L_`vari'_`yr'.dta"
	erase "$maindir${sep}out${sep}$outfolder/PC_L_`vari'_`yr'.dta"
	
	save "$maindir${sep}out${sep}$outfolder/L_`vari'_`yr'.dta", replace
}
clear 
foreach yr of numlist $yrlist{
	
	append using "$maindir${sep}out${sep}$outfolder/L_`vari'_`yr'.dta"
	erase "$maindir${sep}out${sep}$outfolder/L_`vari'_`yr'.dta"	

}

outsheet using "$maindir${sep}out${sep}$outfolder/L_`vari'_sumstat.csv", replace comma

// Collect data across all years and heterogeneity groups. saves one output file per group 
foreach  vv in $hetgroup "male agealt"{

	clear 
	local suf=subinstr("`vv'"," ","",.)
	foreach yr of numlist $yrlist{
		
		use "$maindir${sep}out${sep}$outfolder/S_L_`vari'_`suf'`yr'.dta", clear
		merge 1:1 year `vv' using "$maindir${sep}out${sep}$outfolder/PC_L_`vari'_`suf'`yr'.dta", ///
			nogenerate	
			
		erase "$maindir${sep}out${sep}$outfolder/S_L_`vari'_`suf'`yr'.dta"
		erase "$maindir${sep}out${sep}$outfolder/PC_L_`vari'_`suf'`yr'.dta"
		
		save "$maindir${sep}out${sep}$outfolder/L_`vari'_`suf'`yr'.dta", replace
	}	
	clear 
	foreach yr of numlist $yrlist{
		append using "$maindir${sep}out${sep}$outfolder/L_`vari'_`suf'`yr'.dta"
		erase "$maindir${sep}out${sep}$outfolder/L_`vari'_`suf'`yr'.dta"
	}
	
	outsheet using "$maindir${sep}out${sep}$outfolder/L_`vari'_`suf'_sumstat.csv", replace comma 		
} 	// END loop over heterogeneity group


}	// END loop over variables 


// Collect moments for the permanent income measure

foreach vari in permearn {

foreach yr of numlist $perm3yrlist{

	use "$maindir${sep}out${sep}$outfolder/S_L_`vari'_`yr'.dta", clear
	merge 1:1 year using "$maindir${sep}out${sep}$outfolder/PC_L_`vari'_`yr'.dta", ///
		nogenerate
	erase "$maindir${sep}out${sep}$outfolder/S_L_`vari'_`yr'.dta"
	erase "$maindir${sep}out${sep}$outfolder/PC_L_`vari'_`yr'.dta"
	
	save "$maindir${sep}out${sep}$outfolder/L_`vari'_`yr'.dta", replace
}
clear 
foreach yr of numlist $perm3yrlist{
	
	append using "$maindir${sep}out${sep}$outfolder/L_`vari'_`yr'.dta"
	erase "$maindir${sep}out${sep}$outfolder/L_`vari'_`yr'.dta"	

}

outsheet using "$maindir${sep}out${sep}$outfolder/L_`vari'_sumstat.csv", replace comma

// Collect data across all years and heterogeneity groups. saves one output file per group 
foreach  vv in $hetgroup "male agealt"{

	clear 
	local suf=subinstr("`vv'"," ","",.)
	foreach yr of numlist $perm3yrlist{
		
		use "$maindir${sep}out${sep}$outfolder/S_L_`vari'_`suf'`yr'.dta", clear
		merge 1:1 year `vv' using "$maindir${sep}out${sep}$outfolder/PC_L_`vari'_`suf'`yr'.dta", ///
			nogenerate	
			
		erase "$maindir${sep}out${sep}$outfolder/S_L_`vari'_`suf'`yr'.dta"
		erase "$maindir${sep}out${sep}$outfolder/PC_L_`vari'_`suf'`yr'.dta"
		
		save "$maindir${sep}out${sep}$outfolder/L_`vari'_`suf'`yr'.dta", replace
	}	
	clear 
	foreach yr of numlist $perm3yrlist{
		append using "$maindir${sep}out${sep}$outfolder/L_`vari'_`suf'`yr'.dta"
		erase "$maindir${sep}out${sep}$outfolder/L_`vari'_`suf'`yr'.dta"
	}
	
	outsheet using "$maindir${sep}out${sep}$outfolder/L_`vari'_`suf'_sumstat.csv", replace comma 		
} 	// END loop over heterogeneity group

}	// END loop over variables 

set more off

//Collect data for empirical density (all)
local i=1
foreach yr of numlist $yrlist{

	if mod(`yr',${kyear}) == 0 {
		if(`i'==1){
		use "$maindir${sep}out${sep}$outfolder/L_logearn_`yr'_hist.dta", clear
		erase "$maindir${sep}out${sep}$outfolder/L_logearn_`yr'_hist.dta"
		}
		else{
		merge 1:1 index using "$maindir${sep}out${sep}$outfolder/L_logearn_`yr'_hist.dta", nogen
		erase "$maindir${sep}out${sep}$outfolder/L_logearn_`yr'_hist.dta"
		}
		local i=`i'+1
	}
	
} 
outsheet using "$maindir${sep}out${sep}$outfolder/L_logearn_hist.csv", replace comma


//Collect data for empirical density (male)
local i=1
foreach yr of numlist $yrlist{

	if mod(`yr',${kyear}) == 0 {
		if(`i'==1){
		use "$maindir${sep}out${sep}$outfolder/L_logearn_`yr'_hist_male.dta", clear
		erase "$maindir${sep}out${sep}$outfolder/L_logearn_`yr'_hist_male.dta"
		}
		else{
		merge 1:1 index male using "$maindir${sep}out${sep}$outfolder/L_logearn_`yr'_hist_male.dta", nogen
		erase "$maindir${sep}out${sep}$outfolder/L_logearn_`yr'_hist_male.dta"
		}
		local i=`i'+1
	}
	
} 
	outsheet using "$maindir${sep}out${sep}$outfolder/L_logearn_hist_male.csv", replace comma


// Collect data across years for the concentration measures 
clear
foreach yr of numlist $yrlist{
	append using "$maindir${sep}out${sep}$outfolder/L_earn_`yr'_con.dta"
	erase "$maindir${sep}out${sep}$outfolder/L_earn_`yr'_con.dta"	
} 
	outsheet using "$maindir${sep}out${sep}$outfolder/L_earn_con.csv", replace comma

// Collect data across years for the concentration measures for heterogeneoty groups
	*Men and Women 
	clear
	foreach yr of numlist $yrlist{
		foreach mm in 0 1{
		append using "$maindir${sep}out${sep}$outfolder/L_male`mm'earn_`yr'_con.dta"
		erase "$maindir${sep}out${sep}$outfolder/L_male`mm'earn_`yr'_con.dta"	
		cap:gen male = `mm' 
		cap:replace male = `mm'  if male == .
		}
	} 
		order male
		outsheet using "$maindir${sep}out${sep}$outfolder/L_earn_con_male.csv", replace comma

	*Age	
	clear
	foreach yr of numlist $yrlist{
		foreach mm in 1 2 3{
		append using "$maindir${sep}out${sep}$outfolder/L_age`mm'earn_`yr'_con.dta"
		erase "$maindir${sep}out${sep}$outfolder/L_age`mm'earn_`yr'_con.dta"	
		cap:gen agegp = `mm' 
		cap:replace agegp = `mm'  if agegp == .
		}
	}	
		order agegp
		outsheet using "$maindir${sep}out${sep}$outfolder/L_earn_con_age.csv", replace comma
	*Age and gender
	clear
	foreach yr of numlist $yrlist{
		foreach mm in 1 2 3{	// Age groups
		foreach aa in 0 1 {		// Gender groups
			append using "$maindir${sep}out${sep}$outfolder/L_male`aa'age`mm'earn_`yr'_con.dta"
			erase "$maindir${sep}out${sep}$outfolder/L_male`aa'age`mm'earn_`yr'_con.dta"	
			cap:gen agegp = `mm' 
			cap:replace agegp = `mm'  if agegp == .
			cap:gen male = `aa' 
			cap:replace male = `aa'  if male == .
		}
		}
	}	
		order male agegp
		outsheet using "$maindir${sep}out${sep}$outfolder/L_earn_con_male_age.csv", replace comma
	
	*Educ	
	clear
	foreach yr of numlist $yrlist{
		foreach mm in 1 2 3{
		cap: append using "$maindir${sep}out${sep}$outfolder/L_educ`mm'earn_`yr'_con.dta"
		cap: erase "$maindir${sep}out${sep}$outfolder/L_educ`mm'earn_`yr'_con.dta"	
		cap:gen educ = `mm' 
		cap:replace educ = `mm'  if educ == .
		}
	}	
		order educ
		outsheet using "$maindir${sep}out${sep}$outfolder/L_earn_con_educ.csv", replace comma
		
	*Education and Gender
	clear
	foreach yr of numlist $yrlist{
		foreach mm in 1 2 3{
		foreach aa in 0 1 {
		cap: append using "$maindir${sep}out${sep}$outfolder/L_male`aa'educ`mm'earn_`yr'_con.dta"
		cap: erase "$maindir${sep}out${sep}$outfolder/L_male`aa'educ`mm'earn_`yr'_con.dta"	
		cap:gen educ = `mm' 
		cap:replace educ = `mm'  if educ == .
		cap:gen male = `aa' 
		cap:replace male = `aa'  if male == .
		}
		}
	}	
		order male educ
		outsheet using "$maindir${sep}out${sep}$outfolder/L_earn_con_male_educ.csv", replace comma

// Collects the data on ratios 
	// Over all
	clear
	foreach yr of numlist $yrlist{
			append using "$maindir${sep}out${sep}$outfolder/RI_earn_`yr'_idex.dta"
			erase "$maindir${sep}out${sep}$outfolder/RI_earn_`yr'_idex.dta"	
	} 	
			outsheet using "$maindir${sep}out${sep}$outfolder/RI_earn_idex.csv", replace comma
	
	// By gender
	clear
	forvalues mm = 0/1{
		foreach yr of numlist $yrlist{
			append using "$maindir${sep}out${sep}$outfolder/RI_male`mm'_earn_`yr'_idex.dta"
			erase "$maindir${sep}out${sep}$outfolder/RI_male`mm'_earn_`yr'_idex.dta"	
		} 
		cap: gen male = `mm'
		cap: replace male = `mm' if male == .
	}
		order year male
	outsheet using "$maindir${sep}out${sep}$outfolder/RI_male_earn_idex.csv", replace comma
	
	// By gender age
	clear
	forvalues aa = 1/3{
		forvalues mm = 0/1{
			foreach yr of numlist $yrlist{
				append using "$maindir${sep}out${sep}$outfolder/RI_male`mm'age`aa'_earn_`yr'_idex.dta"
				erase "$maindir${sep}out${sep}$outfolder/RI_male`mm'age`aa'_earn_`yr'_idex.dta"	
			} 
			cap: gen male = `mm'
			cap: replace male = `mm' if male == .
		}
		cap: gen agegp = `aa'
		cap: replace agegp = `aa' if agegp == .
	}
	
	order year male agegp
	outsheet using "$maindir${sep}out${sep}$outfolder/RI_maleagegp_earn_idex.csv", replace comma
	
	
// Collect data from the researn
foreach vari in researne{
	foreach yr of numlist $yrlist{
		use "$maindir${sep}out${sep}$outfolder/S_L_`vari'_`yr'.dta", clear
		merge 1:1 year using "$maindir${sep}out${sep}$outfolder/PC_L_`vari'_`yr'.dta",nogenerate
		erase "$maindir${sep}out${sep}$outfolder/S_L_`vari'_`yr'.dta"
		erase "$maindir${sep}out${sep}$outfolder/PC_L_`vari'_`yr'.dta"		
		save "$maindir${sep}out${sep}$outfolder/L_`vari'_`yr'.dta", replace
	}
	clear 
	foreach yr of numlist $yrlist{		
		append using "$maindir${sep}out${sep}$outfolder/L_`vari'_`yr'.dta"
		erase "$maindir${sep}out${sep}$outfolder/L_`vari'_`yr'.dta"	
	}
	outsheet using "$maindir${sep}out${sep}$outfolder/L_`vari'_sumstat.csv", replace comma
}
	
	

timer off 1
timer list 1

*END OF THE CODE 
