// !!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
// This program generates the time series of Volatility and Higher Order Moments
// First  version January  06, 2019
// This version   January  20, 2022
// Serdar Ozkan and Sergio Salgado
// !!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!

clear all
set more off
// You should change the below directory. 

global maindir =""

// Do not make change from here on. Contact Ozkan/Salgado if changes are needed. 
do "$maindir/do/0_Initialize.do"

// Create folder for output and log-file
global outfolder="19 Mar 2022 Volatility"
capture log close

// Cd to the output file, create the program for moments, and load base sample.
cd "$maindir${sep}out${sep}$outfolder"
do "$maindir${sep}do${sep}myprogs.do"		

// Defines the number of points in the Kernel Density Estimator
global kpoints =  400

// Loop over the years
timer clear 1
timer on 1

 
// Collect data across years  for the 1-year change measure
clear
foreach vari in researn1F arcearn1F{

foreach yr of numlist $d1yrlist{
	local yrp = `yr' - 1

		*Stats 	
		use "$maindir${sep}out${sep}$outfolder/S_L_`vari'_`yr'.dta", clear
		merge 1:1 year using "$maindir${sep}out${sep}$outfolder/PC_L_`vari'_`yr'.dta", ///
			nogenerate
		erase "$maindir${sep}out${sep}$outfolder/S_L_`vari'_`yr'.dta"
		erase "$maindir${sep}out${sep}$outfolder/PC_L_`vari'_`yr'.dta"
		
		save "$maindir${sep}out${sep}$outfolder/L_`vari'_`yr'.dta", replace
				 
		if inlist(`yrp',${perm3yrlist}){
		if inlist(`yr',${d5yrlist}){
			
			
		*Stats per rank
		use "$maindir${sep}out${sep}$outfolder/S_L_`vari'_allrank`yr'.dta", clear
		merge 1:1 year permrank using "$maindir${sep}out${sep}$outfolder/PC_L_`vari'_allrank`yr'.dta", ///
			nogenerate
		erase "$maindir${sep}out${sep}$outfolder/S_L_`vari'_allrank`yr'.dta"
		erase "$maindir${sep}out${sep}$outfolder/PC_L_`vari'_allrank`yr'.dta"
		
		save "$maindir${sep}out${sep}$outfolder/L_`vari'_allrank`yr'.dta", replace
						
		*Stats per rank within age gp
		use "$maindir${sep}out${sep}$outfolder/S_L_`vari'_agerank`yr'.dta", clear
		merge 1:1 year age permrank using "$maindir${sep}out${sep}$outfolder/PC_L_`vari'_agerank`yr'.dta", ///
			nogenerate
		erase "$maindir${sep}out${sep}$outfolder/S_L_`vari'_agerank`yr'.dta"
		erase "$maindir${sep}out${sep}$outfolder/PC_L_`vari'_agerank`yr'.dta"
		
		save "$maindir${sep}out${sep}$outfolder/L_`vari'_agerank`yr'.dta", replace
		
		*Stats per rank within gender
		use "$maindir${sep}out${sep}$outfolder/S_L_`vari'_malerank`yr'.dta", clear
		merge 1:1 year male permrank using "$maindir${sep}out${sep}$outfolder/PC_L_`vari'_malerank`yr'.dta", ///
			nogenerate
		erase "$maindir${sep}out${sep}$outfolder/S_L_`vari'_malerank`yr'.dta"
		erase "$maindir${sep}out${sep}$outfolder/PC_L_`vari'_malerank`yr'.dta"
		
		save "$maindir${sep}out${sep}$outfolder/L_`vari'_malerank`yr'.dta", replace
		
		*Stats per rank within gender/age
		use "$maindir${sep}out${sep}$outfolder/S_L_`vari'_maleagerank`yr'.dta", clear
		merge 1:1 year agegp male permrank using "$maindir${sep}out${sep}$outfolder/PC_L_`vari'_maleagerank`yr'.dta", ///
			nogenerate
		erase "$maindir${sep}out${sep}$outfolder/S_L_`vari'_maleagerank`yr'.dta"
		erase "$maindir${sep}out${sep}$outfolder/PC_L_`vari'_maleagerank`yr'.dta"
		
		save "$maindir${sep}out${sep}$outfolder/L_`vari'_maleagerank`yr'.dta", replace
		
		*Extra top 		
			foreach tto in "all" "age" "male" "maleage"{
				
				local wmerge = ""
				if "`tto'" == "age"{
					local wmerge = "agegp"
				}
				else if "`tto'" == "male"{
					local wmerge = "male"
				}
				else if "`tto'" == "maleage"{
					local wmerge = "male agegp"
				}
				
			foreach uup in T025 T01{
			use "$maindir${sep}out${sep}$outfolder/S_L_`vari'_`tto'rank`uup'`yr'.dta", clear
			merge 1:1 year `wmerge' permrank`uup' using "$maindir${sep}out${sep}$outfolder/PC_L_`vari'_`tto'rank`uup'`yr'.dta", ///
				nogenerate
			erase "$maindir${sep}out${sep}$outfolder/S_L_`vari'_`tto'rank`uup'`yr'.dta"
			erase "$maindir${sep}out${sep}$outfolder/PC_L_`vari'_`tto'rank`uup'`yr'.dta"
		
			save "$maindir${sep}out${sep}$outfolder/L_`vari'_`tto'rank`uup'`yr'.dta", replace
			}
			}
				
		}
		}
	
	***
}

// if inlist("`vari'","researn1F","arcearn1F"){
	
	clear 
	foreach yr of numlist $d1yrlist{
		append using "$maindir${sep}out${sep}$outfolder/L_`vari'_`yr'.dta"
		erase "$maindir${sep}out${sep}$outfolder/L_`vari'_`yr'.dta"	
	}
	outsheet using "$maindir${sep}out${sep}$outfolder/L_`vari'_sumstat.csv", replace comma
		
// }
// else{	
	clear
	foreach yr of numlist $d5yrlist{
		local yrp = `yr' - 1
		if inlist(`yrp',${perm3yrlist}){
		append using "$maindir${sep}out${sep}$outfolder/L_`vari'_allrank`yr'.dta"
		erase "$maindir${sep}out${sep}$outfolder/L_`vari'_allrank`yr'.dta"
		}
	}
	outsheet using "$maindir${sep}out${sep}$outfolder/L_`vari'_allrank.csv", replace comma

	
	clear
	foreach yr of numlist $d5yrlist{
		local yrp = `yr' - 1
		if inlist(`yrp',${perm3yrlist}){
		append using "$maindir${sep}out${sep}$outfolder/L_`vari'_agerank`yr'.dta"
		erase "$maindir${sep}out${sep}$outfolder/L_`vari'_agerank`yr'.dta"
		}
	}
	outsheet using "$maindir${sep}out${sep}$outfolder/L_`vari'_agerank.csv", replace comma
	
	
	clear
	foreach yr of numlist $d5yrlist{
		local yrp = `yr' - 1
		if inlist(`yrp',${perm3yrlist}){
		append using "$maindir${sep}out${sep}$outfolder/L_`vari'_malerank`yr'.dta"
		erase "$maindir${sep}out${sep}$outfolder/L_`vari'_malerank`yr'.dta"
		}
	}
	outsheet using "$maindir${sep}out${sep}$outfolder/L_`vari'_malerank.csv", replace comma

	
	clear
	foreach yr of numlist $d5yrlist{
		local yrp = `yr' - 1
		if inlist(`yrp',${perm3yrlist}){
		append using "$maindir${sep}out${sep}$outfolder/L_`vari'_maleagerank`yr'.dta"
		erase "$maindir${sep}out${sep}$outfolder/L_`vari'_maleagerank`yr'.dta"
		}
	}
	outsheet using "$maindir${sep}out${sep}$outfolder/L_`vari'_maleagerank.csv", replace comma
	
	
	clear	
	foreach tto in "all" "age" "male" "maleage"{
	foreach uup in T025 T01{
		
		clear 
		foreach yr of numlist $d5yrlist{
		local yrp = `yr' - 1
		if inlist(`yrp',${perm3yrlist}){
		
		append using "$maindir${sep}out${sep}$outfolder/L_`vari'_`tto'rank`uup'`yr'.dta"
		erase "$maindir${sep}out${sep}$outfolder/L_`vari'_`tto'rank`uup'`yr'.dta"
		
		}
		}
		outsheet using "$maindir${sep}out${sep}$outfolder/L_`vari'_`tto'rank`uup'.csv", replace comma
		
	}
	}
	
		
// }	// END if statement

// Collect data across all years and heterogeneity groups. saves one database per group 
// if inlist("`vari'","researn1F","arcearn1F"){
	foreach  vv in $hetgroup{

		clear 
		local suf=subinstr("`vv'"," ","",.)
		foreach yr of numlist $d1yrlist{
			
			use "$maindir${sep}out${sep}$outfolder/S_L_`vari'_`suf'`yr'.dta", clear
			merge 1:1 year `vv' using "$maindir${sep}out${sep}$outfolder/PC_L_`vari'_`suf'`yr'.dta", ///
				nogenerate	
				
			erase "$maindir${sep}out${sep}$outfolder/S_L_`vari'_`suf'`yr'.dta"
			erase "$maindir${sep}out${sep}$outfolder/PC_L_`vari'_`suf'`yr'.dta"
			
			save "$maindir${sep}out${sep}$outfolder/L_`vari'_`suf'`yr'.dta", replace
		}	
		clear 
		foreach yr of numlist $d1yrlist{
			append using "$maindir${sep}out${sep}$outfolder/L_`vari'_`suf'`yr'.dta"
			erase "$maindir${sep}out${sep}$outfolder/L_`vari'_`suf'`yr'.dta"
		}
		
		outsheet using "$maindir${sep}out${sep}$outfolder/L_`vari'_`suf'_sumstat.csv", replace comma 		
	} 	// END loop over heterogeneity group
// }	// END if statement
}	// END loop over variables 


// Collect moments for the 5-years change measure
foreach vari in researn5F arcearn5F{

foreach yr of numlist $d5yrlist{

	*Stats
	
		use "$maindir${sep}out${sep}$outfolder/S_L_`vari'_`yr'.dta", clear
		merge 1:1 year using "$maindir${sep}out${sep}$outfolder/PC_L_`vari'_`yr'.dta", ///
			nogenerate
		erase "$maindir${sep}out${sep}$outfolder/S_L_`vari'_`yr'.dta"
		erase "$maindir${sep}out${sep}$outfolder/PC_L_`vari'_`yr'.dta"
		save "$maindir${sep}out${sep}$outfolder/L_`vari'_`yr'.dta", replace

		local yrp = `yr' - 1
		if inlist(`yrp',${perm3yrlist}){
			*Stats per rank
			use "$maindir${sep}out${sep}$outfolder/S_L_`vari'_allrank`yr'.dta", clear
			merge 1:1 year permrank using "$maindir${sep}out${sep}$outfolder/PC_L_`vari'_allrank`yr'.dta", ///
				nogenerate
			erase "$maindir${sep}out${sep}$outfolder/S_L_`vari'_allrank`yr'.dta"
			erase "$maindir${sep}out${sep}$outfolder/PC_L_`vari'_allrank`yr'.dta"
			
			save "$maindir${sep}out${sep}$outfolder/L_`vari'_allrank`yr'.dta", replace
			
			*Stats per rank within age gp
			use "$maindir${sep}out${sep}$outfolder/S_L_`vari'_agerank`yr'.dta", clear
			merge 1:1 year agegp permrank using "$maindir${sep}out${sep}$outfolder/PC_L_`vari'_agerank`yr'.dta", ///
				nogenerate
			erase "$maindir${sep}out${sep}$outfolder/S_L_`vari'_agerank`yr'.dta"
			erase "$maindir${sep}out${sep}$outfolder/PC_L_`vari'_agerank`yr'.dta"
			
			save "$maindir${sep}out${sep}$outfolder/L_`vari'_agerank`yr'.dta", replace
			
			*Stats per rank within male
			use "$maindir${sep}out${sep}$outfolder/S_L_`vari'_malerank`yr'.dta", clear
			merge 1:1 year male permrank using "$maindir${sep}out${sep}$outfolder/PC_L_`vari'_malerank`yr'.dta", ///
				nogenerate
			erase "$maindir${sep}out${sep}$outfolder/S_L_`vari'_malerank`yr'.dta"
			erase "$maindir${sep}out${sep}$outfolder/PC_L_`vari'_malerank`yr'.dta"
			
			save "$maindir${sep}out${sep}$outfolder/L_`vari'_malerank`yr'.dta", replace
			
			*Stats per rank within gender/age
			use "$maindir${sep}out${sep}$outfolder/S_L_`vari'_maleagerank`yr'.dta", clear
			merge 1:1 year agegp male permrank using ///
			"$maindir${sep}out${sep}$outfolder/PC_L_`vari'_maleagerank`yr'.dta", ///
				nogenerate
			erase "$maindir${sep}out${sep}$outfolder/S_L_`vari'_maleagerank`yr'.dta"
			erase "$maindir${sep}out${sep}$outfolder/PC_L_`vari'_maleagerank`yr'.dta"
			
			save "$maindir${sep}out${sep}$outfolder/L_`vari'_maleagerank`yr'.dta", replace
			
			*Extra top 		
			foreach tto in "all" "age" "male" "maleage"{
				
				local wmerge = ""
				if "`tto'" == "age"{
					local wmerge = "agegp"
				}
				else if "`tto'" == "male"{
					local wmerge = "male"
				}
				else if "`tto'" == "maleage"{
					local wmerge = "male agegp"
				}
				
			foreach uup in T025 T01{
			use "$maindir${sep}out${sep}$outfolder/S_L_`vari'_`tto'rank`uup'`yr'.dta", clear
			merge 1:1 year `wmerge' permrank`uup' using "$maindir${sep}out${sep}$outfolder/PC_L_`vari'_`tto'rank`uup'`yr'.dta", ///
				nogenerate
			erase "$maindir${sep}out${sep}$outfolder/S_L_`vari'_`tto'rank`uup'`yr'.dta"
			erase "$maindir${sep}out${sep}$outfolder/PC_L_`vari'_`tto'rank`uup'`yr'.dta"
		
			save "$maindir${sep}out${sep}$outfolder/L_`vari'_`tto'rank`uup'`yr'.dta", replace
			}
			}
					
		
		}
}

	*All stats
	clear 
	foreach yr of numlist $d5yrlist{
		append using "$maindir${sep}out${sep}$outfolder/L_`vari'_`yr'.dta"
		erase "$maindir${sep}out${sep}$outfolder/L_`vari'_`yr'.dta"	
	}
	outsheet using "$maindir${sep}out${sep}$outfolder/L_`vari'_sumstat.csv", replace comma

	
		clear
		foreach yr of numlist $d5yrlist{
			local yrp = `yr' - 1
			if inlist(`yrp',${perm3yrlist}){
			append using "$maindir${sep}out${sep}$outfolder/L_`vari'_allrank`yr'.dta"
			erase "$maindir${sep}out${sep}$outfolder/L_`vari'_allrank`yr'.dta"
			}
		}
			outsheet using "$maindir${sep}out${sep}$outfolder/L_`vari'_allrank.csv", replace comma

		clear
		foreach yr of numlist $d5yrlist{
			local yrp = `yr' - 1
			if inlist(`yrp',${perm3yrlist}){
			append using "$maindir${sep}out${sep}$outfolder/L_`vari'_agerank`yr'.dta"
			erase "$maindir${sep}out${sep}$outfolder/L_`vari'_agerank`yr'.dta"
			}
		}
		outsheet using "$maindir${sep}out${sep}$outfolder/L_`vari'_agerank.csv", replace comma
		
		clear
		foreach yr of numlist $d5yrlist{
			local yrp = `yr' - 1
			if inlist(`yrp',${perm3yrlist}){
			append using "$maindir${sep}out${sep}$outfolder/L_`vari'_malerank`yr'.dta"
			erase "$maindir${sep}out${sep}$outfolder/L_`vari'_malerank`yr'.dta"
			}
		}
		outsheet using "$maindir${sep}out${sep}$outfolder/L_`vari'_malerank.csv", replace comma
		
	clear
	foreach yr of numlist $d5yrlist{
		local yrp = `yr' - 1
		if inlist(`yrp',${perm3yrlist}){
		append using "$maindir${sep}out${sep}$outfolder/L_`vari'_maleagerank`yr'.dta"
		erase "$maindir${sep}out${sep}$outfolder/L_`vari'_maleagerank`yr'.dta"
		}
	}
	outsheet using "$maindir${sep}out${sep}$outfolder/L_`vari'_maleagerank.csv", replace comma
	
	clear	
	foreach tto in "all" "age" "male" "maleage"{
	foreach uup in T025 T01{
		
		clear 
		foreach yr of numlist $d5yrlist{
		local yrp = `yr' - 1
		if inlist(`yrp',${perm3yrlist}){
		
		append using "$maindir${sep}out${sep}$outfolder/L_`vari'_`tto'rank`uup'`yr'.dta"
		erase "$maindir${sep}out${sep}$outfolder/L_`vari'_`tto'rank`uup'`yr'.dta"
		
		}
		}
		outsheet using "$maindir${sep}out${sep}$outfolder/L_`vari'_`tto'rank`uup'.csv", replace comma
		
	}
	}
	

// Collect data across all years and heterogeneity groups. saves one database per group 	
		foreach  vv in $hetgroup{

			clear 
			local suf=subinstr("`vv'"," ","",.)
			foreach yr of numlist $d5yrlist{
				
				use "$maindir${sep}out${sep}$outfolder/S_L_`vari'_`suf'`yr'.dta", clear
				merge 1:1 year `vv' using "$maindir${sep}out${sep}$outfolder/PC_L_`vari'_`suf'`yr'.dta", ///
					nogenerate	
					
				erase "$maindir${sep}out${sep}$outfolder/S_L_`vari'_`suf'`yr'.dta"
				erase "$maindir${sep}out${sep}$outfolder/PC_L_`vari'_`suf'`yr'.dta"
				
				save "$maindir${sep}out${sep}$outfolder/L_`vari'_`suf'`yr'.dta", replace
			}	
			clear 
			foreach yr of numlist $d5yrlist{
				append using "$maindir${sep}out${sep}$outfolder/L_`vari'_`suf'`yr'.dta"
				erase "$maindir${sep}out${sep}$outfolder/L_`vari'_`suf'`yr'.dta"
			}
			
			outsheet using "$maindir${sep}out${sep}$outfolder/L_`vari'_`suf'_sumstat.csv", replace comma 		
		} 	// END loop over heterogeneity group
}	// END loop over variables 

set more off
//Collect data for empirical density 
foreach k in 1 5{
	local i=1
	local j=1
	if `k' == 1{
		foreach yr of numlist $d1yrlist{
			
			if mod(`yr',${kyear}) == 0 {

				if(`i'==1){
				use "$maindir${sep}out${sep}$outfolder/L_researn`k'F_`yr'_hist.dta", clear
				erase "$maindir${sep}out${sep}$outfolder/L_researn`k'F_`yr'_hist.dta"
				}
				else{
				merge 1:1 index using "$maindir${sep}out${sep}$outfolder/L_researn`k'F_`yr'_hist.dta", nogen
				erase "$maindir${sep}out${sep}$outfolder/L_researn`k'F_`yr'_hist.dta"
				}
				local i=`i'+1
				
			}
		} 
		outsheet using "$maindir${sep}out${sep}$outfolder/L_researn`k'F_hist.csv", replace comma
		
		
		foreach yr of numlist $d1yrlist{
			if mod(`yr',${kyear}) == 0 {
				if(`j'==1){
				use "$maindir${sep}out${sep}$outfolder/L_researn`k'F_`yr'_hist_male.dta", clear
				erase "$maindir${sep}out${sep}$outfolder/L_researn`k'F_`yr'_hist_male.dta"
				}
				else{
				merge 1:1 index male using "$maindir${sep}out${sep}$outfolder/L_researn`k'F_`yr'_hist_male.dta", nogen
				erase "$maindir${sep}out${sep}$outfolder/L_researn`k'F_`yr'_hist_male.dta"
				}
				local j=`j'+1
			}
		} 
		outsheet using "$maindir${sep}out${sep}$outfolder/L_researn`k'F_hist_male.csv", replace comma
		
		
	}
	else{
		foreach yr of numlist $d5yrlist{
			if mod(`yr',${kyear}) == 0 {
				if(`i'==1){
				use "$maindir${sep}out${sep}$outfolder/L_researn`k'F_`yr'_hist.dta", clear
				erase "$maindir${sep}out${sep}$outfolder/L_researn`k'F_`yr'_hist.dta"
				}
				else{
				merge 1:1 index using "$maindir${sep}out${sep}$outfolder/L_researn`k'F_`yr'_hist.dta", nogen
				erase "$maindir${sep}out${sep}$outfolder/L_researn`k'F_`yr'_hist.dta"
				}
				local i=`i'+1
			}
		} 
		outsheet using "$maindir${sep}out${sep}$outfolder/L_researn`k'F_hist.csv", replace comma
		
		
		foreach yr of numlist $d5yrlist{
			if mod(`yr',${kyear}) == 0 {
				if(`j'==1){
				use "$maindir${sep}out${sep}$outfolder/L_researn`k'F_`yr'_hist_male.dta", clear
				erase "$maindir${sep}out${sep}$outfolder/L_researn`k'F_`yr'_hist_male.dta"
				}
				else{
				merge 1:1 index male using "$maindir${sep}out${sep}$outfolder/L_researn`k'F_`yr'_hist_male.dta", nogen
				erase "$maindir${sep}out${sep}$outfolder/L_researn`k'F_`yr'_hist_male.dta"
				}
				local j=`j'+1
			}
		} 
		outsheet using "$maindir${sep}out${sep}$outfolder/L_researn`k'F_hist_male.csv", replace comma
	}
}

// Collects data from koncentration measure
	// One year measures
	clear 
	foreach yr of numlist $d1yrlist{
		append using "$maindir${sep}out${sep}$outfolder/PK_researn1F_`yr'.dta"
		erase "$maindir${sep}out${sep}$outfolder/PK_researn1F_`yr'.dta"
	}
		outsheet using "$maindir${sep}out${sep}$outfolder/PK_researn1F.csv", replace comma
	clear 	
	foreach yr of numlist $d1yrlist{
		foreach aa in 1 2 3{
			append using "$maindir${sep}out${sep}$outfolder/PKage_researn1F`aa'_`yr'.dta"
			erase "$maindir${sep}out${sep}$outfolder/PKage_researn1F`aa'_`yr'.dta"
			cap: gen agegp = `aa'
			cap: replace agegp = `aa' if agegp == .
		}
	}	
		order year agegp
		sort year agegp
		outsheet using "$maindir${sep}out${sep}$outfolder/PK_researn1F_age.csv", replace comma
		
	clear 	
	foreach yr of numlist $d1yrlist{
		local yrp = `yr' - 1
		if inlist(`yrp',${perm3yrlist}){
			if inlist(`yr',${d5yrlist}){
			forvalues pp = 1/40{
				append using "$maindir${sep}out${sep}$outfolder/PK_researn1Fp`pp'_`yr'.dta"
				erase "$maindir${sep}out${sep}$outfolder/PK_researn1Fp`pp'_`yr'.dta"
				cap: gen permrank = `pp'
				cap: replace permrank = `pp' if permrank == . 
			}	
				
			}	// IF perminc is possible
		}	// IF 5 years possible
	}	// END loop over years
	order year permrank
	sort year permrank
	outsheet using "$maindir${sep}out${sep}$outfolder/PK_researn1F_permrank.csv", replace comma
	
	clear 	
	foreach yr of numlist $d1yrlist{
		local yrp = `yr' - 1
		if inlist(`yrp',${perm3yrlist}){
			if inlist(`yr',${d5yrlist}){
			forvalues pp = 1/40{
				foreach aa in 1 2 3{
				append using "$maindir${sep}out${sep}$outfolder/PK_researn1Fp`pp'_`aa'_`yr'.dta"
				erase "$maindir${sep}out${sep}$outfolder/PK_researn1Fp`pp'_`aa'_`yr'.dta"
				cap: gen permrank = `pp'
				cap: replace permrank = `pp' if permrank == . 
				cap: gen agegp = `aa'
				cap: replace agegp = `aa' if agegp == .
				}
				}
			}	// IF perminc is possible
		}	// IF 5 years possible
	}	// END loop over years
	order year permrank agegp
	sort year permrank agegp
	outsheet using "$maindir${sep}out${sep}$outfolder/PK_researn1F_permrank_age.csv", replace comma
	
	
	// Five year changes	
	clear 
	foreach yr of numlist $d5yrlist{
		append using "$maindir${sep}out${sep}$outfolder/PK_researn5F_`yr'.dta"
		erase "$maindir${sep}out${sep}$outfolder/PK_researn5F_`yr'.dta"
	}
		outsheet using "$maindir${sep}out${sep}$outfolder/PK_researn5F.csv", replace comma
		
	clear 	
	foreach yr of numlist $d5yrlist{
		foreach aa in 1 2 3{
			append using "$maindir${sep}out${sep}$outfolder/PKage_researn5F`aa'_`yr'.dta"
			erase "$maindir${sep}out${sep}$outfolder/PKage_researn5F`aa'_`yr'.dta"
			cap: gen agegp = `aa'
			cap: replace agegp = `aa' if agegp == .
		}
	}		
	
	order year agegp
	sort year agegp
	outsheet using "$maindir${sep}out${sep}$outfolder/PK_researn5F_age.csv", replace comma
	
	clear 	
	foreach yr of numlist $d1yrlist{
		local yrp = `yr' - 1
		if inlist(`yrp',${perm3yrlist}){
			if inlist(`yr',${d5yrlist}){
			forvalues pp = 1/40{
				cap: append using "$maindir${sep}out${sep}$outfolder/PK_researn5Fp`pp'_`yr'.dta"
				erase "$maindir${sep}out${sep}$outfolder/PK_researn5Fp`pp'_`yr'.dta"
				cap: gen permrank = `pp'
				cap: replace permrank = `pp' if permrank == . 
			}
			}	// IF perminc is possible
		}	// IF 5 years possible
	}	// END loop over years
	order year permrank
	sort year permrank
	outsheet using "$maindir${sep}out${sep}$outfolder/PK_researn5F_permrank.csv", replace comma
	
	clear 	
	foreach yr of numlist $d1yrlist{
		local yrp = `yr' - 1
		if inlist(`yrp',${perm3yrlist}){
			if inlist(`yr',${d5yrlist}){
			forvalues pp = 1/40{
				foreach aa in 1 2 3{
				append using "$maindir${sep}out${sep}$outfolder/PK_researn5Fp`pp'_`aa'_`yr'.dta"
				erase "$maindir${sep}out${sep}$outfolder/PK_researn5Fp`pp'_`aa'_`yr'.dta"
				cap: gen permrank = `pp'
				cap: replace permrank = `pp' if permrank == . 
				cap: gen agegp = `aa'
				cap: replace agegp = `aa' if agegp == .
				}
				}
			}	// IF perminc is possible
		}	// IF 5 years possible
	}	// END loop over years
	order year permrank agegp
	sort year permrank agegp
	outsheet using "$maindir${sep}out${sep}$outfolder/PK_researn5F_permrank_age.csv", replace comma
	
timer off 1
timer list 1

*END OF THE CODE 
