// !!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
// This version September 20, 2021
// Kevin McKinney Serdar Ozkan and Sergio Salgado
// !!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!

clear all
set more off

do path.do

// Read initialize and plotting code. Do not change myplots.do
do "${maindir}/figs/do/0_Initialize.do"
do "${maindir}${sep}figs${sep}do${sep}myplots.do"
do "${maindir}${sep}figs${sep}do${sep}1_Config.do"

// Where the firgures are going to be saved
global outfolder="ineq_init"
capture noisily mkdir "$maindir${sep}figs${sep}${outfolder}"
	
/*----------------------------------------
	Cohorts and Initial Inequality
------------------------------------------*/

	*What is the folder to save plot?
	global folderfile = "$maindir${sep}figs${sep}${outfolder}"	
	

foreach var in logearn{	// Add here other variables 
	foreach subgp in male fem {			// Add here other groups 
	
	// Generates plot for initial wealth inequality
													
	*The code generates for raw earnimgs and residuals earnigs
	global vari = "`var'"		
	
	*Label for plots
	local labtitle = "Log Earnings"
								
	*You can add more groups to this section 
	if "`subgp'" == "all"{
		insheet using "out${sep}${ineqdata}${sep}L_`var'_age_sumstat.csv", clear
		local tlocal = "All Sample"
	}
	if "`subgp'" == "male"{
		insheet using "out${sep}${ineqdata}${sep}L_`var'_maleage_sumstat.csv", clear
		keep if male == 1	// Keep the group we want to plot 
		local tlocal = "Men"
	}	
	if "`subgp'" == "fem"{
		insheet using "out${sep}${ineqdata}${sep}L_`var'_maleage_sumstat.csv", clear
		keep if male == 0	// Keep the group we want to plot 
		local tlocal = "Women"
	}	
			
	*Calculate additional moments 
	gen p99990${vari} = p99_9${vari} - p99${vari}
	gen p9990${vari} = p99${vari} - p90${vari}
	gen p9010${vari} = p90${vari} - p10${vari}	
	gen p9050${vari} = p90${vari} - p50${vari}
	gen p5010${vari} = p50${vari} - p10${vari}
	gen ksk${vari} = (p9050${vari} - p5010${vari})/p9010${vari}

	*Gen cohort that is the age at which cohort was 25 years old 
	gen cohort25 = year - age + 25
	order year age cohort25
		
			 			
// Plots at the age of entry

	foreach ageval in 25{
	preserve
		*Keep only the sub sample at the age of age val 
		keep if age == `ageval'
		
		*Rescale by first year 
		foreach vv in sd$vari p1$vari p2_5$vari p5$vari p10$vari p12_5$vari p25$vari ///
			p37_5$vari p50$vari p62_5$vari p75$vari p87_5$vari p90$vari p95$vari ///
			p97_5$vari p99$vari p99_9$vari p99_99$vari{
			
			sum  `vv' if year == ${yrfirst}, meanonly
			gen n`vv' = `vv' - r(mean)
			
			}
		*Recessions bars 
		gen rece = inlist(year,${receyears})

		*What is the last year in the x axis 
		local rlast = ${yrlast}

	// 	*Plots
		
	// Percentiles
		tspltAREALimPA "p9050${vari} p5010${vari}" /// Which variables?
	   "year" ///
	   ${yrfirst} `rlast' 3 /// Limits of x and y axis. Example: x axis is -.1(0.05).1 
	   "P90-P50" "P50-P10" "" "" "" "" "" "" "" /// Labels 
	   "1" "11" ///
	   "" /// x axis title
	   "Dispersion of `labtitle'" /// y axis title 
	   "" ///  Plot title
	   ""  /// 	 Plot subtitle  
	   "fig3_`subgp'_${vari}"	/// Figure name
	   "0.6" "1.8" "0.2"				/// ylimits
		"" 						/// If legend is active or nor	
		"red blue forest_green purple gray orange green"			/// Colors
		 "O S x D" 	
		 
	restore
	
	} // END of loop over age val		
	
	// Plots by cohorts 			
	*Which variable is under analysis? 
	*The code generates for raw earnimgs and residuals earnigs
	global vari = "`var'"		
	
	*Label for plots
	local labtitle = "log y{sub:it}"
								
	*You can add more groups to this section 
	if "`subgp'" == "all"{
		insheet using "out${sep}${ineqdata}${sep}L_`var'_age_sumstat.csv", clear
		local tlocal = "All Sample"
	}
	if "`subgp'" == "male"{
		insheet using "out${sep}${ineqdata}${sep}L_`var'_maleage_sumstat.csv", clear
		keep if male == 1	// Keep the group we want to plot 
		local tlocal = "Men"
		
		*Age 25
		local posi1= 2.28
		local posi2= 2.15
		local posi3= 2.3
		
		local yposi1= 2000
		local yposi2= 1998
		local yposi3= 2002.5
		
		*Age 35
		local posj1= 2.45
		local posj2= 2.31
		local posj3= 2.45
		
		local yposj1= 2007
		local yposj2= 2008
		local yposj3= 2007
		
	}	
	if "`subgp'" == "fem"{
		insheet using "out${sep}${ineqdata}${sep}L_`var'_maleage_sumstat.csv", clear
		keep if male == 0	// Keep the group we want to plot 
		local tlocal = "Women"
		
		*Age 25
		local posi1= 2.28
		local posi2= 2.13
		local posi3= 2.3
		
		local yposi1= 2000
		local yposi2= 1998
		local yposi3= 2002.5
		
		*Age 35
		local posj1= 2.45
		local posj2= 2.38
		local posj3= 2.45
		
		local yposj1= 2007
		local yposj2= 2008
		local yposj3= 2007
	}
		
	*Calculate additional moments 
	gen p99990${vari} = p99_9${vari} - p99${vari}
	gen p9990${vari} = p99${vari} - p90${vari}
	gen p9010${vari} = p90${vari} - p10${vari}	
	gen p9050${vari} = p90${vari} - p50${vari}
	gen p5010${vari} = p50${vari} - p10${vari}
	gen ksk${vari} = (p9050${vari} - p5010${vari})/p9010${vari}

	*Gen cohort that is the age at which cohort was 25 years old 
	gen cohort25 = year - age + 25
	order year age cohort25
	
	

	gkswplot_co "p9010`var'" "year" ///
			 "1998 2000 2005 2009" /// what cohorts?
			 "25 35 45 50" /// What ages: code allows three
			 "1998" "2019" "5" /// x-axis
			 "on" "7" "2" "Cohort 1998" "Cohort 2000" "Cohort 2005" "Cohort 2009" /// Legends
			 "" "P90-P10 of Log Earnigs"  /// x and y titles 
			 "" "large" "" "" ///
			 "2" "2.5" "0.1" ///
			 "fig3B_`subgp'_${vari}" ///
			 "`posi1'" "`yposi1'" "`posi2'" "`yposi2'" "`posi3'" "`yposi3'" "25 yrs old" ///
			 "`posj1'" "`yposj1'" "`posj2'" "`yposj2'" "`posj3'" "`yposj3'" "35 yrs old" 

	
}	// END loop subgroups
}	// END loop over variables 
