// !!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
// This version September 20, 2021
// Kevin McKinney Serdar Ozkan and Sergio Salgado
// !!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!

clear all
set more off

do path.do

// Read initialize and plotting code. Do not change myplots.do
do "${maindir}/figs/do/0_Initialize.do"
do "${maindir}${sep}figs${sep}do${sep}myplots.do"
do "${maindir}${sep}figs${sep}do${sep}1_Config.do"

// Where the firgures are going to be saved
global outfolder="egrow_het"
capture noisily mkdir "$maindir${sep}figs${sep}${outfolder}"

/*---------------------------------------------------	
    Income growth heterogeneity 
 ---------------------------------------------------*/	
	
		foreach mm in  0 1{		// 0: Women; 1: Men; 2: All		
		foreach jj in  1 5{
		local var = "researn`jj'F"
		global vari = "`var'"

		*What is the label for title 
		if "${vari}"== "researn1F"{
			local labtitle = "g{sup:1}{sub:it}"
			global folderfile = "$maindir${sep}figs${sep}${outfolder}"	
		}
		if "${vari}" == "researn5F"{
			local labtitle = "g{sup:5}{sub:it}"
			global folderfile = "$maindir${sep}figs${sep}${outfolder}"	
		}
	 
		*Load the data for the last percentile
		insheet using "out${sep}${voladata}${sep}L_`var'_maleagerank.csv", clear case
		
		*Calculate additional moments 
		gen p9010${vari} = p90${vari} - p10${vari}
		gen p9050${vari} = p90${vari} - p50${vari}
		gen p5010${vari} = p50${vari} - p10${vari}
		gen p7525${vari} = p75${vari} - p25${vari}
		gen ksk${vari} = (p9050${vari} - p5010${vari})/p9010${vari}
		gen cku${vari} = (p97_5${vari} - p2_5${vari})/p7525${vari} - 2.91		// Excess Kurtosis
		replace kurt${vari} = kurt${vari} - 3.0		// Excess Kurtosis
		
		if `mm' == 1{
			keep if male == `mm'
			local lname = "men"
			local mlabel = "Men"
		}
		else if `mm' == 0{
			keep if male == `mm'
			local lname = "women"
			local mlabel = "Women"
		}
		
						
		collapse  p9010${vari} p9050${vari} p5010${vari} sd${vari} ksk${vari} skew${vari} cku${vari} kurt${vari}, by(agegp permrank)
		reshape wide p9010${vari} p9050${vari} p5010${vari} sd${vari} ksk${vari} skew${vari} cku${vari} kurt${vari}, i(permrank) j(agegp)
		
		*Idex for plot: the code calculates the top 0.1% in a seperated group (group 42). Since some countries might have 
		*top coded values, we do not plot the top 0.1%
		gen idex = _n
		order idex 
	
		*Figure A		
		if "${vari}" == "researn1F"{
			local ylimlo = 0.0
			local ylimup = 2.2
			local ylimdf = 0.5			
		}		
		if "${vari}" == "researn5F"{
			local ylimlo = 0.5
			local ylimup = 3.5
			local ylimdf = 0.5		
		}
		
		tw (connected p9010${vari}1 p9010${vari}2 p9010${vari}3 permrank if idex<=42, msymbol(none none o)  ///
		color(red blue green) lpattern(solid dash dash_dot) lwidth(thick thick thick)), ///
		xlabel(2.5 "0" 10 "10" 20 "20" 30 "30" 40 "40" 50 "50" 60 "60" 70 "70" 80 "80" 90 "90" 100 "100", labsize(${xlabsize}) grid) ///
		graphregion(color(white)) plotregion(lcolor(black)) ///
		legend(ring(0) position(2) order(1 "[25-34]" 2 "[35-44]" 3 "[45-55]") size(${legesize}) cols(1) symxsize(7) region(color(none))) ///
		xtitle("Quantiles of Permanent Residual Log Earnings p{sub:it-1}", size(${xtitlesize})) ///
		ytitle("P90-P10 Differential of `labtitle'", size(${ytitlesize})) ///
		title("", color(black) size(${titlesize})) ylabel(`ylimlo'(`ylimdf')`ylimup', format(%9.1f) labsize(${ylabsize}))		
		graph export "${folderfile}/fig6A_${vari}_`lname'.${formatfile}", width($gwidth) replace 
			
		*Figure B	
		if "${vari}" == "researn1F"{
			local ylimlo = -0.3
			local ylimup = 0.3
			local ylimdf = 0.1			
		}		
		if "${vari}" == "researn5F"{
			local ylimlo = -0.3
			local ylimup = 0.3
			local ylimdf = 0.1		
		}
		
		tw (connected ksk${vari}1 ksk${vari}2 ksk${vari}3 permrank if idex<=42, msymbol(none none o) ///
		color(red blue green) lpattern(solid dash dash_dot) lwidth(thick thick thick)), ///
		xlabel(2.5 "0" 10 "10" 20 "20" 30 "30" 40 "40" 50 "50" 60 "60" 70 "70" 80 "80" 90 "90" 100 "100", labsize(${xlabsize}) grid) ///
		graphregion(color(white)) plotregion(lcolor(black)) ///
		legend(ring(0) position(2) order(1 "[25-34]" 2 "[35-44]" 3 "[45-55]") size(${legesize}) cols(1) symxsize(7) region(color(none))) ///
		xtitle("Quantiles of Permanent Residual Log Earnings p{sub:it-1}", size(${xtitlesize}))  ///
		ytitle("Kelley Skewness of `labtitle'", size(${ytitlesize})) ///
		title("", color(black) size(${titlesize})) ylabel(`ylimlo'(`ylimdf')`ylimup', format(%9.1f) labsize(${ylabsize})) yline(0,lcolor(black) lpattern(dash))
		graph export "${folderfile}/fig6B_${vari}_`lname'.${formatfile}", width($gwidth) replace 
				
		*Figure C
		if "${vari}" == "researn1F"{
			local ylimlo = 1
			local ylimup = 15
			local ylimdf = 2
		}		
		if "${vari}" == "researn5F"{
			local ylimlo = 1
			local ylimup = 8
			local ylimdf = 2	
		}
		
		tw (connected cku${vari}1 cku${vari}2 cku${vari}3 permrank if idex<=42, msymbol(none none o) ///
		color(red blue green) lpattern(solid dash dash_dot) lwidth(thick thick thick)), ///
		xlabel(2.5 "0" 10 "10" 20 "20" 30 "30" 40 "40" 50 "50" 60 "60" 70 "70" 80 "80" 90 "90" 100 "100", labsize(${xlabsize}) grid) ///
		graphregion(color(white)) plotregion(lcolor(black)) ///
		legend(ring(0) position(11) order(1 "[25-34]" 2 "[35-44]" 3 "[45-55]") size(${legesize}) cols(1) symxsize(7) region(color(none))) ///
		xtitle("Quantiles of Permanent Residual Log Earnings p{sub:it-1}", size(${xtitlesize}))  ///
		ytitle("Excess Crow-Siddiqui Kurtosis of `labtitle'", size(${ytitlesize})) ///
		title("", color(black) size(medium)) ylabel(`ylimlo'(`ylimdf')`ylimup', format(%9.1f) labsize(${ylabsize}))
		graph export "${folderfile}/fig6C_${vari}_`lname'.${formatfile}", width($gwidth) replace 	
		
		
		*For appendix
		*Figure AA
		
		if "${vari}" == "researn1F"{
			local ylimlo = 0.20
			local ylimup = 1
			local ylimdf = .20
		}		
		if "${vari}" == "researn5F"{
			local ylimlo = 0.3
			local ylimup = 1.5
			local ylimdf = 0.3	
		}
		
		tw (connected sd${vari}1 sd${vari}2 sd${vari}3 permrank if idex<=42, msymbol(none none o)  ///
		color(red blue green) lpattern(solid dash dash_dot) lwidth(thick thick thick)), ///
		xlabel(2.5 "0" 10 "10" 20 "20" 30 "30" 40 "40" 50 "50" 60 "60" 70 "70" 80 "80" 90 "90" 100 "100", labsize(${xlabsize}) grid) ///
		graphregion(color(white)) plotregion(lcolor(black)) ///
		legend(ring(0) position(2) order(1 "[25-34]" 2 "[35-44]" 3 "[45-55]") size(${legesize}) cols(1) symxsize(7) region(color(none))) ///
		xtitle("Quantiles of Permanent Residual Log Earnings p{sub:it-1}", size(${xtitlesize}))  ///
		ytitle("Standard Deviation of `labtitle'", size(${ytitlesize})) ///
		title("", color(black) size(medium)) ylabel(`ylimlo'(`ylimdf')`ylimup', format(%9.1f) labsize(${ylabsize}))
		graph export "${folderfile}/fig6A_${vari}_`lname'_ct.${formatfile}", width($gwidth) replace 		
		
			
		*Figure BB			
		if "${vari}" == "researn1F"{
			local ylimlo = -4
			local ylimup = 0
			local ylimdf = 1
		}		
		if "${vari}" == "researn5F"{
			local ylimlo = -4
			local ylimup = 0
			local ylimdf = 1
		}
		
		tw (connected skew${vari}1 skew${vari}2 skew${vari}3 permrank if idex<=42, msymbol(none none o) ///
		color(red blue green) lpattern(solid dash dash_dot) lwidth(thick thick thick)), ///
		xlabel(2.5 "0" 10 "10" 20 "20" 30 "30" 40 "40" 50 "50" 60 "60" 70 "70" 80 "80" 90 "90" 100 "100", labsize(${xlabsize}) grid) ///
		graphregion(color(white)) plotregion(lcolor(black)) ///
		legend(ring(0) position(7) order(1 "[25-34]" 2 "[35-44]" 3 "[45-55]") size(${legesize}) cols(1) symxsize(7) region(color(none))) ///
		xtitle("Quantiles of Permanent Residual Log Earnings p{sub:it-1}", size(${xtitlesize}))  ///
		ytitle("Skewness of `labtitle'", size(${ytitlesize})) ///
		title("", color(black) size(medium)) ylabel(`ylimlo'(`ylimdf')`ylimup', format(%9.1f) labsize(${ylabsize}))  yline(0,lcolor(black) lpattern(dash))
		graph export "${folderfile}/fig6B_${vari}_`lname'_ct.${formatfile}", width($gwidth) replace 
		
		*Figure CC
		if "${vari}" == "researn1F"{
			local ylimlo = 0
			local ylimup = 60
			local ylimdf = 10
		}		
		if "${vari}" == "researn5F"{
			local ylimlo = 0
			local ylimup = 30
			local ylimdf = 5
		}
		
		tw (connected kurt${vari}1 kurt${vari}2 kurt${vari}3 permrank if idex<=42, msymbol(none none o) ///
		color(red blue green) lpattern(solid dash dash_dot) lwidth(thick thick thick)), ///
		xlabel(2.5 "0" 10 "10" 20 "20" 30 "30" 40 "40" 50 "50" 60 "60" 70 "70" 80 "80" 90 "90" 100 "100", labsize(${xlabsize}) grid) ///
		graphregion(color(white)) plotregion(lcolor(black)) ///
		legend(ring(0) position(11) order(1 "[25-34]" 2 "[35-44]" 3 "[45-55]") size(${legesize}) cols(1) symxsize(7) region(color(none))) ///
		xtitle("Quantiles of Permanent Residual Log Earnings p{sub:it-1}", size(${xtitlesize}))  ///
		ytitle("Excess Kurtosis of `labtitle'", size(${ytitlesize})) ///
		title("", color(black) size(medium)) ylabel(`ylimlo'(`ylimdf')`ylimup', format(%9.1f) labsize(${ylabsize})) yline(0,lcolor(black) lpattern(dash))
		graph export "${folderfile}/fig6C_${vari}_`lname'_ct.${formatfile}", width($gwidth) replace 	
		
		}	// END loop variables		
		}	// END loop men/women	
