// !!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
// This version September 20, 2021
// Kevin McKinney Serdar Ozkan and Sergio Salgado
// !!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!

clear all
set more off

do path.do

// Read initialize and plotting code. Do not change myplots.do
do "${maindir}/figs/do/0_Initialize.do"
do "${maindir}${sep}figs${sep}do${sep}myplots.do"
do "${maindir}${sep}figs${sep}do${sep}1_Config.do"

// Where the firgures are going to be saved
global outfolder="mob"
capture noisily mkdir "$maindir${sep}figs${sep}${outfolder}"

/* T+5 Years */
global yrkla=2000
global yrklb=2014

/* T+10 Years */
global yrklc=2000
global yrkld=2009

/*----------------------------------------------
	Mobility
------------------------------------------------*/
	
	*What is the folder to save files 
	global folderfile = "$maindir${sep}figs${sep}${outfolder}"	
		
		foreach mm in  0 1{			/*Gender: Men 1; Women 0*/		
		/*Load Data*/
		insheet using "out${sep}${mobidata}${sep}L_male_agegp_permearnalt_mobstat.csv", clear			
		keep if male == `mm'
		collapse meanpermearnaltranktp5 [aw=npermearnaltranktp5], by(permearnaltrankt year)
		keep meanpermearnaltranktp5 permearnaltrankt year
		reshape wide meanpermearnaltranktp5 , i(permearnaltrankt) j(year)
		gen idex = _n
		
		*T+5
		cap: drop  y1 x1 y2 x2
		if `mm' == 1{			
			gen y1 = 95 if _n == 1
			gen x1 = 85 if _n == 1
			gen y2 = 95 if _n == 1
			gen x2 = 97 if _n == 1
			local t1pos = 95
			local t2pos = 85 
		
		}
		else{
			gen y1 = 95 if _n == 1
			gen x1 = 85 if _n == 1
			gen y2 = 95 if _n == 1
			gen x2 = 97 if _n == 1
			local t1pos = 95
			local t2pos = 85 
		}
		tw  (line meanpermearnaltranktp5${yrkla} meanpermearnaltranktp5${yrklb} permearnaltrankt permearnaltrankt if idex<= 41, ///
			color(red blue black) lpattern(solid dash dash) lwidth(thick thick )) ///
			(scatter meanpermearnaltranktp5${yrkla} meanpermearnaltranktp5${yrklb} permearnaltrankt if idex==42, ///
			color(red blue green) lpattern(dash dash dash) msymbol(D S O)  msize(large large large) ) ///
			(pcarrow y1 x1 y2 x2, msize(medlarge) mlwidth(medthick) mlcolor(black) lcolor(black) ), ///
			text(`t1pos' `t2pos' "Top 0.1% of p3{sub:it}", place(w) size(large))  ///
			legend(ring(0) position(11) order(1 "${yrkla}" 2 "${yrklb}") size(large) cols(1) symxsize(7) region(color(none))) ///
			xtitle("Percentiles of Permanent Earnings, p3{sub:it}", size(large)) title("", color(black) size(medlarge)) ///
			xlabel(2.5 "0" 10 "10" 20 "20" 30 "30" 40 "40" 50 "50" 60 "60" 70 "70" 80 "80" 90 "90" 99 "99.9", labsize(large) grid) ///
			graphregion(color(white)) plotregion(lcolor(black)) ///
			ytitle("Mean Percentiles of p3{sub:it+5}", color(black) size(large)) ylabel(,labsize(large))									
			graph export "${folderfile}/fig7_mobility_male`mm'_yrs_T5.${formatfile}", width($gwidth) replace 
			
		*T+10
		insheet using "out${sep}${mobidata}${sep}L_male_agegp_permearnalt_mobstat.csv", clear			
		keep if male == `mm'
		collapse meanpermearnaltranktp10 [aw=npermearnaltranktp10], by(permearnaltrankt year)
		keep meanpermearnaltranktp10 permearnaltrankt year
		reshape wide meanpermearnaltranktp10 , i(permearnaltrankt) j(year)
		gen idex = _n
		
		cap: drop  y1 x1 y2 x2
		if `mm' == 1{	
			gen y1 = 90 if _n == 1
			gen x1 = 85 if _n == 1
			gen y2 = 90 if _n == 1
			gen x2 = 97 if _n == 1
			local t1pos = 90
			local t2pos = 85 
				   			
		}
		else{			
			gen y1 = 90 if _n == 1
			gen x1 = 85 if _n == 1
			gen y2 = 90 if _n == 1
			gen x2 = 97 if _n == 1
			local t1pos = 90
			local t2pos = 85 

		}
			
		tw  (line meanpermearnaltranktp10${yrklc} meanpermearnaltranktp10${yrkld} permearnaltrankt permearnaltrankt if idex<= 41, ///
			color(red blue black) lpattern(solid dash dash) lwidth(thick thick)) ///
			(scatter meanpermearnaltranktp10${yrklc} meanpermearnaltranktp10${yrkld} permearnaltrankt if idex==42, ///
			color(red blue green) lpattern(dash dash dash) msymbol(D S O)  msize(large large large) ) ///
			(pcarrow y1 x1 y2 x2, msize(medlarge) mlwidth(medthick) mlcolor(black) lcolor(black) ), ///
			text(`t1pos' `t2pos' "Top 0.1% of p3{sub:it}", place(w) size(large))  ///
			legend(ring(0) position(11) order(1 "${yrklc}" 2 "${yrkld}") size(large) cols(1) symxsize(7) region(color(none))) ///
			xtitle("Percentiles of Permanent Earnings, p3{sub:it}", size(large)) title("", color(black) size(medlarge)) ///
			xlabel(0(10)90 99, labsize(large) grid) graphregion(color(white)) plotregion(lcolor(black)) ///
			ytitle("Mean Percentiles of p3{sub:it+10}", color(black) size(large)) ylabel(,labsize(large))			
			graph export "${folderfile}/fig7_mobility_male`mm'_yrs_T10.${formatfile}", width($gwidth) replace 
		
	/*--- Mobility by age group---*/			
				
		/*Load Data*/
		insheet using "out${sep}${mobidata}${sep}L_male_agegp_permearnalt_mobstat.csv", clear
		keep if male == `mm'
		collapse meanpermearnaltranktp5, by(permearnaltrankt agegp)
		keep meanpermearnaltranktp5 permearnaltrankt agegp
		reshape wide meanpermearnaltranktp5 , i(permearnaltrankt) j(agegp)
		gen idex = _n
		
		/*T+5 mobility*/
		cap: drop  y1 x1 y2 x2
		if `mm' == 1{			
			gen y1 = 95 if _n == 1
			gen x1 = 85 if _n == 1
			gen y2 = 95 if _n == 1
			gen x2 = 97 if _n == 1
			local t1pos = 95
			local t2pos = 85 
		
		}
		else{
			gen y1 = 95 if _n == 1
			gen x1 = 85 if _n == 1
			gen y2 = 95 if _n == 1
			gen x2 = 97 if _n == 1
			local t1pos = 95
			local t2pos = 85 
		}
						
		tw  (line meanpermearnaltranktp51 meanpermearnaltranktp52 meanpermearnaltranktp53 permearnaltrankt permearnaltrankt if idex<= 41, ///
			color(red blue green black) lpattern(solid dash dash_dot dash) lwidth(thick thick thick)) ///
			(scatter meanpermearnaltranktp51 meanpermearnaltranktp52 meanpermearnaltranktp53 permearnaltrankt if idex==42, ///
			color(red blue green) lpattern(dash dash dash) msymbol(D S O)  msize(large large large) ) ///
			(pcarrow y1 x1 y2 x2, msize(medlarge) mlwidth(medthick) mlcolor(black) lcolor(black) ), ///
			text(`t1pos' `t2pos' "Top 0.1% of p3{sub:it}", place(w) size(large))  ///
			legend(ring(0) position(11) order(1 "[25-34]" 2 "[35-44]" 3 "[45-55]") size(large) cols(1) symxsize(7) region(color(none))) ///
			xtitle("Percentiles of Permanent Earnings, p3{sub:it}", size(large)) title("", color(black) size(medlarge)) ///
			xlabel(2.5 "0" 10 "10" 20 "20" 30 "30" 40 "40" 50 "50" 60 "60" 70 "70" 80 "80" 90 "90" 99 "99.9", labsize(large) grid) ///
			graphregion(color(white)) plotregion(lcolor(black)) ///
			ytitle("Mean Percentiles of p3{sub:it+5}", color(black) size(large)) ylabel(,labsize(large))						
			graph export "${folderfile}/fig7_mobility_male`mm'_T5.${formatfile}", width($gwidth) replace 
		
			 
		/*T+10 mobility*/
		insheet using "out${sep}${mobidata}${sep}L_male_agegp_permearnalt_mobstat.csv", clear
		keep if male == `mm'
		collapse meanpermearnaltranktp10, by(permearnaltrankt agegp)
		keep meanpermearnaltranktp10 permearnaltrankt agegp
		reshape wide meanpermearnaltranktp10 , i(permearnaltrankt) j(agegp)
		gen idex = _n
		
		cap: drop  y1 x1 y2 x2
		if `mm' == 1{	
			gen y1 = 90 if _n == 1
			gen x1 = 85 if _n == 1
			gen y2 = 90 if _n == 1
			gen x2 = 97 if _n == 1
			local t1pos = 90
			local t2pos = 85 
				   			
		}
		else{			
			gen y1 = 90 if _n == 1
			gen x1 = 85 if _n == 1
			gen y2 = 90 if _n == 1
			gen x2 = 97 if _n == 1
			local t1pos = 90
			local t2pos = 85 

		}	
		tw  (line meanpermearnaltranktp101 meanpermearnaltranktp102 permearnaltrankt permearnaltrankt if idex<= 41, ///
			color(red blue black) lpattern(solid dash dash) lwidth(thick thick)) ///
			(scatter meanpermearnaltranktp101 meanpermearnaltranktp102 permearnaltrankt if idex==42, ///
			color(red blue green) lpattern(dash dash dash) msymbol(D S O)  msize(large large large) ) ///
			(pcarrow y1 x1 y2 x2, msize(medlarge) mlwidth(medthick) mlcolor(black) lcolor(black) ), ///
			text(`t1pos' `t2pos' "Top 0.1% of p3{sub:it}", place(w) size(large))  ///
			legend(ring(0) position(11) order(1 "[25-34]" 2 "[35-44]") size(large) cols(1) symxsize(7) region(color(none))) ///
			xtitle("Percentiles of Permanent Earnings, p3{sub:it}", size(large)) title("", color(black) size(medlarge)) ///
			xlabel(0(10)90 99, labsize(large) grid) graphregion(color(white)) plotregion(lcolor(black)) ///
			ytitle("Mean Percentiles of p3{sub:it+10}", color(black) size(large)) ylabel(,labsize(large))		
			graph export "${folderfile}/fig7_mobility_male`mm'_T10.${formatfile}", width($gwidth) replace 
	}	// END loop over men and women	
