// !!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
// This version September 20, 2021
// Kevin McKinney Serdar Ozkan and Sergio Salgado
// !!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!

clear all
set more off

do path.do

// Read initialize and plotting code. Do not change myplots.do
do "${maindir}/figs/do/0_Initialize.do"
do "${maindir}${sep}figs${sep}do${sep}myplots.do"
do "${maindir}${sep}figs${sep}do${sep}1_Config.do"

// Where the firgures are going to be saved
global outfolder="tail"
capture noisily mkdir "$maindir${sep}figs${sep}${outfolder}"

/*---------------------------------------------------	
    Tail For Appendix 
 ---------------------------------------------------*/
	
	global folderfile = "$maindir${sep}figs${sep}${outfolder}"
	
	*Load and reshape data 		
	forvalues mm = 0/2{			/*0: Women; 1: Men; 2: All*/
				
		if `mm' == 1{
			insheet using "out${sep}${ineqdata}${sep}RI_male_earn_idex.csv", clear comma 
			keep if male == `mm'
			local llabel = "Male"
		}
		else if `mm' == 0{
			insheet using "out${sep}${ineqdata}${sep}RI_male_earn_idex.csv", clear comma 
			keep if male == `mm'
			local llabel = "Women"		
		}
		else {
			insheet using "out${sep}${ineqdata}${sep}RI_earn_idex.csv", clear comma 			
		}
				
		reshape long t me ra ob, i(year) j(level) string
		split level, p(level) 
		drop level1
		rename level2 numlevel
		destring numlevel, replace 
		order numlevel level year 
		sort year numlevel
		
		*Re scale and share of pop
		by year: gen aux = 20*ob if numlevel == 0 
		by year: egen tob = max(aux)   // Because ob is number of observations in top 5%
		drop aux
		by year: gen  shob = ob/tob
				 gen  lshob = log(shob)		  	
		
		gen t1000s = (t/1000)/${exrate2018}				// Tranform to dollars of 2018
		gen lt1000s = log(t1000s)
		gen lt = log(t)
		gen l10t = log10(t)
		
		*Re-reshape 
		reshape wide t me ra ob tob shob lshob t1000s lt l10t lt1000s, i(numlevel) j(year)
		
		
		/*5% Tail*/
		regress lshob2000 lt2000
		predict lshob2000_hat, xb
		global slopep2000 : di %4.2f _b[lt2000]
		
		regress lshob2015 lt2015
		predict lshob2015_hat, xb
		global slopep2015 : di %4.2f _b[lt2015]
				
		tw (line lshob2000 lshob2000_hat lt2000, color(red red) lwidth(thick) lpattern(solid dash)) ///
			(line  lshob2015 lshob2015_hat lt2015 , color(blue blue)  lwidth(thick) lpattern(solid dash)) , ///
		legend(ring(0) position(2) ///
			order(1 "2000 Level (Slope: ${slopep2000})" 3 "2015 Level (Slope: ${slopep2015})") size(medium) cols(1) symxsize(7) region(color(none))) ///
			 xtitle("log y{sub:it}", size(${xtitlesize})) title(, color(black) size(medlarge)) ///
			  xlabel(, grid labsize(${xlabsize})) graphregion(color(white)) plotregion(lcolor(black)) ///
			 ytitle("log(1-CDF)", color(black) size(${ytitlesize})) ylabel(,labsize(${ylabsize}))
			 graph export "${folderfile}/logCDF_5pct_`llabel'.${formatfile}", width($gwidth) replace 
		drop lshob2015_hat lshob2000_hat
		
		/*1% Tail*/		
		regress lshob2000 lt2000 if shob2000 < 0.01
		predict lshob2000_hat if e(sample), xb
		global slopep2000 : di %4.2f _b[lt2000]
		
		regress lshob2015 lt2015 if shob2015 < 0.01
		predict lshob2015_hat if e(sample), xb
		global slopep2015 : di %4.2f _b[lt2015]
				
		tw (line lshob2000 lshob2000_hat lt2000    if shob2000 < 0.01, color(red red) lwidth(thick) lpattern(solid dash)) ///
			(line  lshob2015 lshob2015_hat lt2015  if shob2015 < 0.01, color(blue blue)  lwidth(thick) lpattern(solid dash)) , ///
		legend(ring(0) position(2) order(1 "2000 Level (Slope: ${slopep2000})" 3 "2015 Level (Slope: ${slopep2015})") ///
		size(medium) cols(1) symxsize(7) region(color(none))) ///
			 xtitle("log y{sub:it}", size(${xtitlesize})) title(, color(black) size(medlarge)) ///
			  xlabel(, grid labsize(${xlabsize})) graphregion(color(white)) plotregion(lcolor(black)) ///
			 ytitle("log(1-CDF)", color(black) size(${ytitlesize})) ylabel(,labsize(${ylabsize}))
			 graph export "${folderfile}/logCDF_1pct_`llabel'.${formatfile}", width($gwidth) replace 
		drop lshob2015_hat lshob2000_hat
		
	}
