// !!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
// This version September 20, 2021
// Kevin McKinney Serdar Ozkan and Sergio Salgado
// !!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!

clear all
set more off

do path.do

// Read initialize and plotting code. Do not change myplots.do
do "${maindir}/figs/do/0_Initialize.do"
do "${maindir}${sep}figs${sep}do${sep}myplots.do"
do "${maindir}${sep}figs${sep}do${sep}1_Config.do"

// Where the firgures are going to be saved
global outfolder="conc"
capture noisily mkdir "$maindir${sep}figs${sep}${outfolder}"

/*---------------------------------------------------	
    This section generates the figures 3b in the
	Common Core section of the Guidelines
 ---------------------------------------------------*/	

	*Folder to save figures 
	global folderfile = "$maindir${sep}figs${sep}${outfolder}"	
	
	foreach subgp in male fem   all{
	*You can add more groups to this section 
	if "`subgp'" == "all"{
		insheet using  "out${sep}${ineqdata}${sep}L_earn_con.csv", clear
		local tlocal = "All Sample"
	}
	if "`subgp'" == "male"{
		insheet using "out${sep}${ineqdata}${sep}L_earn_con_male.csv", clear
		keep if male == 1	// Keep the group we want to plot 
		local tlocal = "Men"
	}	
	if "`subgp'" == "fem"{
		insheet using "out${sep}${ineqdata}${sep}L_earn_con_male.csv", clear
		keep if male == 0	// Keep the group we want to plot 
		local tlocal = "Women"
	}
	
	
	*Normalizing data to value in ${normyear}
	local lyear = ${normyear}	// Normalization year
	foreach vv in q1share q2share q3share q4share q5share ///
				  top10share top5share top1share top05share top01share top001share ///
				  bot50share{
		
		sum  `vv' if year == `lyear', meanonly
		gen n`vv' = (`vv' - r(mean))/100
		
		}
		
	*What years 
	local rlast = ${yrlast}
	
	*Recession bars 
	gen rece = inlist(year,${receyears})
	
	
	*Joint Quintiles Figures
	tspltAREALimZero "nq1share nq2share nq3share nq4share nq5share" /// Which variables?
		   "year" ///
		   ${yrfirst} `rlast' 3 /// Limits of x and y axis. Example: x axis is -.1(0.05).1 
		   "Q1" "Q2" "Q3" "Q4" "Q5" "" "" "" "" /// Labels 
		    "1" "11" ///
		   "" /// x axis title
		   "Earn Share Change Relative to `lyear'" /// y axis title 
		   "" ///  Plot title
		   ""  /// 	 Plot subtitle  (left blank in this example)
		   "fig11B_nquintile_more_`subgp'"	/// Figure name
		   "-0.04" "0.06" "0.02"				/// ylimits
		   "" 						/// If legend is active or nor	
	       "green black maroon red navy blue forest_green purple gray orange"	/// Colors
		   "solid solid solid solid solid solid solid solid" ///
		   "O T D S T dh sh th dh sh x none"
		   
		tspltAREALimZero "nbot50share ntop10share ntop5share ntop1share ntop05share ntop01share ntop001share" /// Which variables?
		   "year" ///
		   ${yrfirst} `rlast' 3 /// Limits of x and y axis. Example: x axis is -.1(0.05).1 
		   "Bottom 50%" "Top 10%" "Top 5%" "Top 1%" "Top 0.5%" "Top 0.1%" "Top 0.01%" "" "" /// Labels 
		    "1" "11" ///
		   "" /// x axis title
		   "Earn Share Change Relative to `lyear'" /// y axis title 
		   "" ///  Plot title
		   ""  /// 	 Plot subtitle  (left blank in this example)
		   "fig11B_bot50share_more_`subgp'"	/// Figure name
		   "-0.04" "0.06" "0.02"				/// ylimits
		   "" 						/// If legend is active or nor	
	       "green black maroon red navy blue forest_green purple gray orange"	/// Colors
		   "solid solid solid solid solid solid solid solid" ///
		   "O T D S T dh sh th dh sh x none"
		   
		   
	*Gini
	tspltAREALim2 "gini" /// Which variables?
		   "year" ///
		   ${yrfirst} `rlast' 3 /// Limits of x and y axis. Example: x axis is -.1(0.05).1 
		   "Gini" "" "" "" "" "" "" "" "" /// Labels 
		   "1" "11" ///
		   "" /// x axis title
		   "Gini Coefficient" /// y axis title 
		   "" ///  Plot title
		   ""  /// 	 Plot subtitle  (left blank in this example)
		   "fig3b_gini_`subgp'"	/// Figure name
		   "0.4" "0.5" "0.02"				/// ylimits
		   "off" 						/// If legend is active or nor	
		   "blue red"			// Colors
		   
		   
}	// END of loop over variables
