*** Round CSV Files ***;

*** OPTIONS ***;
options spool mlogic mprint symbolgen fullstimer msglevel=i ps=200 ls=200 nocenter obs=max;

libname dot ".";

%put SASUSER path=%sysfunc(pathname(sasuser));

%let sigfig=4;

%macro drb;
   proc import datafile="../&fdir/&fname..csv"
      out=temp0
      dbms=csv
      replace;
   run;
   proc print data=temp0;
   run;
   data dlist1(drop=i vlist);
      set temp0;

      array numv{*} _NUMERIC_;

      /* en.wikipedia.org/wiki/Significant_figures */;

      /* Formula
         x = input variable
         p = number of significant digits to retain for input variable x
         v = output variable
         n = floor(log10(x))+1-p
         v = round(x*10**-n)*10**n
      */;

      array parm{3} _TEMPORARY_;

      do i=1 to dim(numv);
         vlist=numv{i};

         if vlist=. or vlist=0 then parm{1}=0;
         else if vlist>0 then parm{1}=1;
         else if vlist<0 then parm{1}=2;

         if parm{1}=1 then do;
            parm{3}=vlist;
            parm{2}=floor(log10(parm{3}))+1-&sigfig;
            vlist=(round(parm{3}*10**-parm{2})*10**parm{2});
         end;
         else if parm{1}=2 then do;
            parm{3}=abs(vlist);
            parm{2}=floor(log10(parm{3}))+1-&sigfig;
            vlist=-(round(parm{3}*10**-parm{2})*10**parm{2});
         end;
         numv{i}=vlist;
      end;
   run;

   title1 "################################################################################ ";
   title2 "### Sample [&samp.] # Variable [&var.] # Program [&prog.] # Result File [&fname..csv] ###";
   proc print data=dlist1;
   run;
   proc export data=dlist1
      outfile="./&fname..csv"
      dbms=csv
      replace;
   run;
   proc export data=dlist1
      outfile="./gid_data_bin_round.xlsx"
      dbms=xlsx;
      newfile=no;
      sheet="%substr(&fname,1,31)";
   run;
%mend;

x "rm -f gid_data_bin_round.xlsx";

*** Disclosure File 1 ****;
/* Sample:      */; %let samp  = base;
/* Variable:    */; %let var   = logearn;
/* Program:     */; %let prog  = stata;
/* Folder:      */; %let fdir = 7 Oct 2021 Inequality;
/* Result File: */; %let fname = L_logearn_male_sumstat;
%drb;

*** Disclosure File 2 ****;
/* Sample:      */; %let samp  = base;
/* Variable:    */; %let var   = logearn;
/* Program:     */; %let prog  = stata;
/* Folder:      */; %let fdir = 7 Oct 2021 Inequality;
/* Result File: */; %let fname = L_logearn_maleage_sumstat;
%drb;

*** Disclosure File 3 ****;
/* Sample:      */; %let samp  = base;
/* Variable:    */; %let var   = researn1F;
/* Program:     */; %let prog  = stata;
/* Folder:      */; %let fdir = run4_vol;
/* Result File: */; %let fname = L_researn1F_male_sumstat;
%drb;

*** Disclosure File 4 ****;
/* Sample:      */; %let samp  = base;
/* Variable:    */; %let var   = researn1F;
/* Program:     */; %let prog  = stata;
/* Folder:      */; %let fdir = run4_vol;
/* Result File: */; %let fname = L_researn1F_maleagerank;
%drb;

*** Disclosure File 5 ****;
/* Sample:      */; %let samp  = base;
/* Variable:    */; %let var   = permearnalt;
/* Program:     */; %let prog  = stata;
/* Folder:      */; %let fdir = 7 Oct 2021 Mobility;
/* Result File: */; %let fname = L_male_agegp_permearnalt_mobstat;
%drb;

*** Disclosure File 6 ****;
/* Sample:      */; %let samp  = base;
/* Variable:    */; %let var   = logearn;
/* Program:     */; %let prog  = stata;
/* Folder:      */; %let fdir = 7 Oct 2021 Inequality;
/* Result File: */; %let fname = L_logearn_sumstat;
%drb;

*** Disclosure File 7 ****;
/* Sample:      */; %let samp  = base;
/* Variable:    */; %let var   = researn;
/* Program:     */; %let prog  = stata;
/* Folder:      */; %let fdir = 7 Oct 2021 Inequality;
/* Result File: */; %let fname = L_researn_sumstat;
%drb;

*** Disclosure File 8 ****;
/* Sample:      */; %let samp  = base;
/* Variable:    */; %let var   = researne;
/* Program:     */; %let prog  = stata;
/* Folder:      */; %let fdir = 7 Oct 2021 Inequality;
/* Result File: */; %let fname = L_researne_sumstat;
%drb;

*** Disclosure File 9 ****;
/* Sample:      */; %let samp  = base;
/* Variable:    */; %let var   = labor (earn);
/* Program:     */; %let prog  = stata;
/* Folder:      */; %let fdir = 7 Oct 2021 Inequality;
/* Result File: */; %let fname = RI_male_earn_idex;
%drb;

*** Disclosure File 10 ****;
/* Sample:      */; %let samp  = base;
/* Variable:    */; %let var   = labor (earn);
/* Program:     */; %let prog  = stata;
/* Folder:      */; %let fdir = 7 Oct 2021 Inequality;
/* Result File: */; %let fname = L_earn_con;
%drb;

*** Disclosure File 11 ****;
/* Sample:      */; %let samp  = base;
/* Variable:    */; %let var   = researn5F;
/* Program:     */; %let prog  = stata;
/* Folder:      */; %let fdir = run4_vol;
/* Result File: */; %let fname = L_researn5F_male_sumstat;
%drb;

*** Disclosure File 12 ****;
/* Sample:      */; %let samp  = base;
/* Variable:    */; %let var   = researn5F;
/* Program:     */; %let prog  = stata;
/* Folder:      */; %let fdir = run4_vol;
/* Result File: */; %let fname = L_researn5F_maleagerank;
%drb;

*** Disclosure File 13 ****;
/* Sample:      */; %let samp  = base;
/* Variable:    */; %let var   = researn;
/* Program:     */; %let prog  = stata;
/* Folder:      */; %let fdir = 7 Oct 2021 Inequality;
/* Result File: */; %let fname = L_researn_male_sumstat;
%drb;

*** Disclosure File 14 ****;
/* Sample:      */; %let samp  = base;
/* Variable:    */; %let var   = labor (earn);
/* Program:     */; %let prog  = stata;
/* Folder:      */; %let fdir = 7 Oct 2021 Inequality;
/* Result File: */; %let fname = RI_earn_idex;
%drb;

*** Disclosure File 15 ****;
/* Sample:      */; %let samp  = base;
/* Variable:    */; %let var   = labor (earn);
/* Program:     */; %let prog  = stata;
/* Folder:      */; %let fdir = 7 Oct 2021 Inequality;
/* Result File: */; %let fname = L_earn_con_male;
%drb;

*** Disclosure File 16 ****;
/* Sample:      */; %let samp  = base;
/* Variable:    */; %let var   = researn1F;
/* Program:     */; %let prog  = stata;
/* Folder:      */; %let fdir = run4_vol;
/* Result File: */; %let fname = L_researn1F_hist_male;
%drb;

*** Disclosure File 17 ****;
/* Sample:      */; %let samp  = base;
/* Variable:    */; %let var   = researn5F;
/* Program:     */; %let prog  = stata;
/* Folder:      */; %let fdir = run4_vol;
/* Result File: */; %let fname = L_researn5F_hist_male;
%drb;
