*** Output SAS and Stata Files for Analaysis ***;

%include "config.sas";

proc options option=(memsize sumsize sortsize) define;
run;


data outputs.usa_&begyr._&endyr.(drop=_merge) checkit(keep=_merge insamp regime)
     outputs.stata_input(keep=personid year male YOB YOD educ earn_ann regime1 regime2 regime3 regime);
   merge outputs.uipikyear(in=a) outputs.uipik_icf_cnum(in=b drop=_merge);
      by pik;

   length _merge jobsok regime1 regime2 regime3 regime 3;

   _merge=a+2*b;

   regime1=not (dom_state in ("DE","IA","NE","UT","OK","VT","AL","MA","DC","AR","NH","MS")) and
           year<=2015;

   regime2=year>=2004 and year<=2015;

   regime3=not (dom_state in ("AK", "AR", "MS")) and
           year>=2004;

   if regime2=1 then regime=1;
   else if year<2004 and regime1=1 then regime=1;
   else if year>2015 and regime3=1 then regime=1;

   jobsok=njobs<=12;

   insamp=jobsok=1 and cnum=1;

   label
   YOB="Year of Birth"
   YOD="Year of Death"
   cnum="On Numident"
   dom_sein="Dominant SEIN"
   dom_state="Dominant State"
   earn_ann="Annual Earnings All Jobs"
   earn_max="Earn High Pay Job"
   educ="Education 4 Cat"
   insamp="jobsok and cnum"
   jobsok="njobs<=12"
   male="Male=1"
   njobs="Number of Jobs Year"
   personid="Numeric Person ID"
   regime1="39 States Available 1998-2015"
   regime2="51 States Available 2004-2015"
   regime3="48 States Available 2004-2020"
   regime="Sample with 2003-2004 and 2015-2016 Seams"
   ;

   output outputs.usa_&begyr._&endyr.;
   output checkit;
   if insamp=1 then output outputs.stata_input;
run;

proc contents data=outputs.usa_&begyr._&endyr.;
proc contents data=outputs.stata_input;
options nolabel;
proc tabulate data=checkit;
   class _merge insamp regime /missing;
   table _merge all, n*f=comma14.0 pctn;
   table insamp all, n*f=comma14.0 pctn;
   table regime all, n*f=comma14.0 pctn;
   table _merge*insamp*(regime all='Subtotal') all='Total'
         , n*f=comma14.0 pctn<regime all> pctn;
run;
proc means data=outputs.usa_&begyr._&endyr.;
   class regime jobsok cnum /missing;
   var earn_ann earn_max njobs;
run;
proc means data=outputs.usa_&begyr._&endyr.;
   class year;
   var earn_ann earn_max njobs;
run;
proc means data=outputs.usa_&begyr._&endyr.(where=(insamp=1 and regime=1));
   class year;
   var earn_ann earn_max njobs;
run;
proc freq data=outputs.usa_&begyr._&endyr. noprint;
   tables regime1*year*dom_state /noprint missing out=reg1;
   tables regime2*year*dom_state /noprint missing out=reg2;
   tables regime3*year*dom_state /noprint missing out=reg3;
   tables regime*year*dom_state /noprint missing out=reg;
run;

proc summary data=reg1 nway;
   class regime1 year;
   output out=reg1s(drop=_TYPE_ rename=(_FREQ_=num_st)) sum(COUNT)=num_recs;
run;
proc contents data=reg1s;
proc print data=reg1s(where=(regime1=1));
run;

proc summary data=reg2 nway;
   class regime2 year;
   output out=reg2s(drop=_TYPE_ rename=(_FREQ_=num_st)) sum(COUNT)=num_recs;
run;
proc contents data=reg2s;
proc print data=reg2s(where=(regime2=1));
run;

proc summary data=reg3 nway;
   class regime3 year;
   output out=reg3s(drop=_TYPE_ rename=(_FREQ_=num_st)) sum(COUNT)=num_recs;
run;
proc contents data=reg3s;
proc print data=reg3s(where=(regime3=1));
run;

proc summary data=reg nway;
   class regime year;
   output out=regs(drop=_TYPE_ rename=(_FREQ_=num_st)) sum(COUNT)=num_recs;
run;
proc contents data=regs;
proc print data=regs(where=(regime=1));
run;

proc tabulate data=outputs.usa_&begyr._&endyr.(where=(regime=1));
   class insamp dom_state jobsok njobs cnum male educ year /missing;
   table dom_state all, n*f=comma14.0 pctn;
   table jobsok*(cnum all='Subtotal') all='Total'
         , n*f=comma14.0 pctn<cnum all> pctn;
   table insamp*(njobs all='Subtotal') all='Total'
         , n*f=comma14.0 pctn<njobs all> pctn;
   table insamp*(dom_state all='Subtotal') all='Total'
         , n*f=comma14.0 pctn<dom_state all> pctn;
   table insamp*(male all='Subtotal') all='Total'
         , n*f=comma14.0 pctn<male all> pctn;
   table insamp*(educ all='Subtotal') all='Total'
         , n*f=comma14.0 pctn<educ all> pctn;
run;
proc print data=outputs.usa_&begyr._&endyr.(obs=100);
run;
