*** Create Stata Datasets ***;
*** Create a dataset that accounts for state missingness ***;

%include "config.sas";

%let begin_age=25;
%let end_age=55;

data indat(keep=personid year dom_state male YOB YOD educ earn_ann regime1 regime2 regime3 regime) /view=indat;
   set outputs.usa_&begyr._&endyr.;

   if insamp=1 and regime=1 then output;
run;

data outputs.stata_input_alt(drop=regime1 regime2 regime3 regime fyr eyr fyr_ds eyr_ds yr25 yr55 ageok fyr2 eyr2 dom_state i);
*data stata_input(drop=regime1 regime2 regime3 regime fyr eyr fyr_ds eyr_ds yr25 yr55 ageok fyr2 eyr2 dom_state i);
*data stata_input(drop=regime1 regime2 regime3 regime i);
   set indat;
      by personid;

   retain fyr eyr fyr_ds eyr_ds;

   array ea{&begyr:&endyr} _TEMPORARY_ (&nyrs.*0);

   if first.personid then do;
      fyr=year;
      fyr_ds=dom_state in ("DE","IA","NE","UT","OK","VT","AL","MA","DC","AR","NH","MS");
   end;

   ea{year}=earn_ann;

   if last.personid then do;
      eyr=year;
      eyr_ds=dom_state in ("AK", "AR", "MS");
      yr25=YOB+&begin_age-1;
      yr55=YOB+&end_age-1;
      ageok=((&begyr<=yr25<=&endyr) or (&begyr<=yr55<=&endyr)) or (yr25<=&begyr and yr55>=&endyr);
      if ageok then do;
         if &begyr<yr25 then fyr2=yr25; else fyr2=&begyr;
         if &endyr>yr55 then eyr2=yr55; else eyr2=&endyr;
         if fyr_ds and fyr2<2004 then fyr2=2004;
         if eyr_ds and eyr2>2015 then eyr2=2015;
         do i=fyr2 to eyr2;
            year=i;
            earn_ann=ea{i};
            output;
         end;
      end;
      do i=fyr to eyr;
         ea{i}=0;
      end;
   end;
run;

endsas;

proc contents data=stata_input;
proc means data=stata_input(where=(earn_ann>0));
run;
proc print data=stata_input(obs=1000);
*proc print data=stata_input(where=(yr25<2004 and fyr<=2004 and yr25<fyr));
*proc print data=stata_input(where=(yr55>2015 and eyr>=2015 and yr55>eyr));
run;

proc export data=stata_input(obs=1600000000)
   file="../dta/usa1.dta"
   dbms=dta replace;
run;

proc export data=stata_input(firstobs=1600000001)
   file="../dta/usa2.dta"
   dbms=dta replace;
run;

data tempran(drop=randraw persout);
   set stata_input;
      by personid;

   retain persout;

   randraw=rand('UNIFORM');

   if first.personid and randraw<0.01 then persout=1;

   if persout=1 then output tempran;

   if last.personid then persout=.;
run;

proc contents data=tempran;
proc means data=tempran;
run;
proc print data=tempran(obs=100);
run;

proc export data=tempran
   file="../dta/usa_sample.dta"
   dbms=dta replace;
run;
