*** Macro to calculate DRB approved percentiles ***;

%macro ptiles(idat,odat,sorder,slast,vname);
   proc sort data=&idat. out=sdat;
      by &sorder &vname.;
   run;
   
   proc contents data=sdat;
   run;
   
   proc summary data=sdat nway;
      class &sorder;
      output out=stats_cnt(drop=_TYPE_ _FREQ_) n(&vname.)=so_n
                                               P1(&vname.)=P_1
                                               P5(&vname.)=P_5
                                               P10(&vname.)=P_10
                                               Q1(&vname.)=P_25
                                               median(&vname.)=P_50
                                               Q3(&vname.)=P_75
                                               P90(&vname.)=P_90
                                               P95(&vname.)=P_95
                                               P99(&vname.)=P_99;
   run;
   
   proc print data=stats_cnt;
   run;
   
   data &odat.(drop=&vname. i np01--np99);
      merge sdat stats_cnt(keep=&sorder so_n);
         by &sorder;
   
      retain n_w np01 np05 np10 np25 np50 np75 np90 np95 np99
                 de01 de05 de10 de25 de50 de75 de90 de95 de99
                 P_01 P_05 P_10 P_25 P_50 P_75 P_90 P_95 P_99;
   
      array np{*} np01 np05 np10 np25 np50 np75 np90 np95 np99;
      array de{*} de01 de05 de10 de25 de50 de75 de90 de95 de99;
      array pt{*} P_01 P_05 P_10 P_25 P_50 P_75 P_90 P_95 P_99;
   
      if first.&slast then do;
         n_w=0;
         np{1}=ceil(so_n*0.01);
         np{2}=ceil(so_n*0.05);
         np{3}=ceil(so_n*0.10);
         np{4}=ceil(so_n*0.25);
         np{5}=ceil(so_n*0.50);
         np{6}=ceil(so_n*0.75);
         np{7}=ceil(so_n*0.90);
         np{8}=ceil(so_n*0.95);
         np{9}=ceil(so_n*0.99);
         do i=1 to dim(np);
            de{i}=0;
            pt{i}=0;
         end;
      end;
   
      n_w=n_w+1;
   
      do i=1 to dim(np); 
         if n_w>=(np{i}-5) and n_w<=(np{i}+5) then do;
            de{i}=de{i}+1;
            pt{i}=pt{i}+&vname.;
         end;
      end;
   
      if last.&slast then do;
         do i=1 to dim(np);
            pt{i}=pt{i}/de{i};
         end;
         output;
      end;
   run;
   
   proc contents data=&odat.;
   proc print data=&odat.;
   run;
%mend;
