*** Get Information on and Select the Analysis Sample ***;

%include "../config.sas";
%include "../00_macros/pik2short.sas";
%include "../00_macros/sline.sas";


data temp0 /view=temp0;
   %sline(lib=outputs,data=iv_work,keepvars=_ALL_);
run;

*** Calculate Firm Vars ***;

data merge_s1;
   set temp0(keep=pik earn_pce state ind2012 ces_age ui_age ces_size ui_size);
run;

proc summary data=merge_s1 nway;
   class pik state;
   output out=state(drop=_TYPE_ _FREQ_) sum(earn_pce)=size;
run;

proc sort data=state;
   by pik descending size;
run;

data state2(keep=pik state rename=(state=st_dom)) /view=state2;
   set state;
      by pik;
   if first.pik then output;
run;

proc summary data=merge_s1 nway;
   class pik ind2012;
   output out=ind(drop=_TYPE_ _FREQ_) sum(earn_pce)=size;
run;

proc sort data=ind;
   by pik descending size;
run;

data ind2(keep=pik ind2012 rename=(ind2012=ind_dom)) /view=ind2;
   set ind;
      by pik ;
   if first.pik then output;
run;

proc summary data=merge_s1 nway;
   weight earn_pce;
   class pik;
   output out=agesize(drop=_TYPE_ _FREQ_) mean(ces_age ui_age ces_size ui_size)=ces_age_dom ui_age_dom ces_size_dom ui_size_dom;
run;

data ecfchars;
   merge state2 ind2 agesize;
      by pik;
run;

proc contents data=ecfchars;
proc freq data=ecfchars;
   tables st_dom ind_dom /list missing;
run;
proc means data=ecfchars;
   var ces_age_dom ui_age_dom ces_size_dom ui_size_dom;
run;
proc print data=ecfchars(obs=100);
run;


*** Put Everything Together ***;

data outputs.pik_year_vars(drop=full partial inactive ftspells last_wrk earn_all check wrk_hist log_earn_all i ndiff ediff_m ediff_v)
     outputs.pik_vars(keep=pik age_cohort born_US ethnicity first_age first_year in_sample last_year pchar race sex educ_c slength work_ever
                   full partial inactive earn_all log_earn_all ftspells wrk_hist ndiff ediff_m ediff_v
                   st_dom ind_dom ces_age_dom ui_age_dom ces_size_dom ui_size_dom
                   ea_st_p ea_ind_p ea1 ea2 ea3);

   merge temp0 ecfchars;
      by pik;

   retain full partial inactive ftspells last_wrk earn_all ea_st ea_ind ea1 ea2 ea3;

   length active full partial inactive ndiff ftspells last_wrk ea_st ea_ind 3;

   array ep{&begyr:&endyr} _TEMPORARY_;
   array ped{&begyrd:&endyrd} _TEMPORARY_;

   if first.pik then do;
      full=0;
      partial=0;
      inactive=0;
      if wrk4all=0 then ftspells=0;
      else ftspells=1;
      earn_all=0;
      do i=&begyr to &endyr;
         ep{i}=0;
      end;
      do i=&begyrd to &endyrd;
         ped{i}=.;
      end;
      ea_st=0;
      ea_ind=0;
      ea1=0;
      ea2=0;
      ea3=0;
   end;

   active=earn_pce>0;

   if active=1 then log_earn_pce=log(earn_pce);

   if wrk4all=1 then full=full+1;
   else if wrk4all=0 and earn_pce>0 then partial=partial+1;
   else inactive=inactive+1;

   earn_all=earn_all+earn_pce;

   if not(first.pik) then do;
      if last_wrk=0 and wrk4all=1 then ftspells=ftspells+1;
   end;

   last_wrk=wrk4all;

   ep{year}=earn_pce;

   if state=st_dom then ea_st=ea_st+earn_pce;
   if ind2012=ind_dom then ea_ind=ea_ind+earn_pce;

   if year>=2004 and year<=2007 then ea1=ea1+earn_pce;
   else if year>=2008 and year<=2011 then ea2=ea2+earn_pce;
   else if year>=2012 and year<=2015 then ea3=ea3+earn_pce;

   if last.pik then do;
      check=full+partial+inactive;
      if (inactive=0 and full=12) then wrk_hist=4;
      else if (inactive=0 and full<12) or (inactive=1 and full>=7) or
         (inactive=2 and full>=7) then wrk_hist=3;
      else if (inactive>=8) or (inactive=7 and full<=3) or
              (inactive=6 and full<=2) then wrk_hist=1;
      else wrk_hist=2;
      if earn_all>0 then do;
         ea_st_p=round(100*(ea_st/earn_all));
         ea_ind_p=round(100*(ea_ind/earn_all));
         earn_all=earn_all/12;
         log_earn_all=log(earn_all);
      end;
      ndiff=0;
      do i=&begyrd to &endyrd;
         if ep{i}>0 or ep{i-1}>0 then do;
            ndiff=ndiff+1;
            ped{i}=(ep{i}-ep{i-1})/((ep{i}+ep{i-1})/2);
         end;
      end;
      if ndiff>0 then ediff_m=mean(of ped{*});

      if ndiff>1 then ediff_v=var(of ped{*});
      else if ndiff>0 then ediff_v=0;

      ea1=ea1/4;
      ea2=ea2/4;
      ea3=ea3/4;

      output outputs.pik_vars;
   end;

   output outputs.pik_year_vars;
run;

*** Person Statistics ***;
proc contents data=outputs.pik_vars;
proc means data=outputs.pik_vars;
run;
proc print data=outputs.pik_vars(obs=100);
run;

proc contents data=outputs.pik_year_vars;
proc means data=outputs.pik_year_vars;
run;
proc print data=outputs.pik_year_vars(obs=100);
run;
