*** Get HC Estimates ***;

%include "../config.sas";

* HC Estimates *;
libname hc "";

libname dot ".";


data temp1 /view=temp1;
   set hc.hcest2(keep=pik year ln_real_ann_earn theta psi where=(year>=2004 and year<=2015));
run;

data temp2(keep=pik theta psi_pik) /view=temp2;
   set temp1;
      by pik;

   retain yp yp_f yp_nf;

   if first.pik then do;
      yp=0;
      yp_f=0;
      yp_nf=0;
   end;

   y=exp(ln_real_ann_earn);
   y_f=y-exp(ln_real_ann_earn-psi);
   y_nf=y-y_f;

   yp=yp+y;
   yp_f=yp_f+y_f;
   yp_nf=yp_nf+y_nf;

   if last.pik then do;
      psi_pik=log(yp)-log(yp_nf);
      output;
   end;

   label psi_pik="psi avg 2004-2015";
run;  

proc contents data=temp2;
proc print data=temp2(obs=100);
run;

data temp3;
   merge outputs.pik_vars(keep=pik in_sample earn_all in=a) temp2(in=b);
      by pik;

   length _merge 3;

   _merge=a+2*b;

   if a=1 then output;
run;

proc contents data=temp3;
proc freq data=temp3;
   tables in_sample*_merge /list missing;
run;
proc means data=temp3;
   class in_sample _merge;
   var earn_all theta psi_pik;
run;
proc corr data=temp3;
run;
proc print data=temp3(obs=100);
run;
   
*** Impute Missing Theta and Psi Values ***;

proc summary data=temp3(where=(in_sample=1 and _merge=3));
   output out=mean_sd(drop=_TYPE_ _FREQ_) mean(theta psi_pik)=theta_m psi_pik_m std(theta psi_pik)=theta_sd psi_pik_sd;
run;

data outputs.hc_est(keep=pik in_sample theta psi_pik);
   set temp3;

   if _N_=1 then set mean_sd;

   if in_sample=1 and _merge=1 then do;
      theta=rand('NORMAL',theta_m,theta_sd);
      psi_pik=rand('NORMAL',psi_pik_m,psi_pik_sd);
   end;
run;

proc contents data=outputs.hc_est;
proc means data=outputs.hc_est;
   class in_sample;
run;
proc print data=outputs.hc_est(obs=100);
run;
