*** Compute Earnings Measures for Different Earnings Quantile Rangees ***;

%include "../config.sas";


*** Earnings Statistics at PCHAR Quantiles ***;

proc univariate data=outputs.pik_vars_2 noprint;
   class pchar;
   var earn_all;
   output out=dot.pchar_quant pctlpre=P_ pctlpts=9 11 24 26 49 51 74 76 89 91;
run;

proc contents data=dot.pchar_quant;
proc print data=dot.pchar_quant;
run;

data temp1(keep=pchar qcat earn_all active3 eda13_0 eda13_1 ediff_v first_age hours full partial inactive theta psi_pik ltmob region ind_dom educ_c);
   set outputs.pik_vars_2(keep=pchar earn_all ea1 ea2 ea3 ediff_m ediff_v theta psi_pik hours full partial inactive st_dom ind_dom first_age educ_c rename=(hours=hours_temp));

   length qcat $2;

   array pc{1:20} $4 _TEMPORARY_;
   array qt{1:20,1:10} _TEMPORARY_;

   if _N_=1 then do;
      do i=1 to 20;
         set dot.pchar_quant;
         pc{i}=pchar;
         qt{i,1}=P_9;
         qt{i,2}=P_11;
         qt{i,3}=P_24;
         qt{i,4}=P_26;
         qt{i,5}=P_49;
         qt{i,6}=P_51;
         qt{i,7}=P_74;
         qt{i,8}=P_76;
         qt{i,9}=P_89;
         qt{i,10}=P_91;
      end;
   end;

   row=0;
   stop=0;
   do i=1 to 20 until(stop=1);
      if pchar=pc{i} then do;
         row=i;
         stop=1;
      end;
   end;

   qcat="00";
   if earn_all>qt{row,1} and earn_all<=qt{row,2} then qcat="10";
   else if earn_all>qt{row,3} and earn_all<=qt{row,4} then qcat="25";
   else if earn_all>qt{row,5} and earn_all<=qt{row,6} then qcat="50";
   else if earn_all>qt{row,7} and earn_all<=qt{row,8} then qcat="75";
   else if earn_all>qt{row,9} and earn_all<=qt{row,10} then qcat="90";

   length region 3;

   if st_dom in ("CT", "ME", "MA", "NH", "RI", "VT") then region=1;
   else if st_dom in ("NJ", "NY", "PA") then region=2;
   else if st_dom in ("IL", "IN","MI", "OH", "WI") then region=3;
   else if st_dom in ("IA", "KS", "MN", "MO", "NE", "ND", "SD") then region=4;
   else if st_dom in ("DE", "FL", "GA", "MD", "NC", "SC", "VA", "DC", "WV") then region=5;
   else if st_dom in ("AL", "KY", "MS", "TN") then region=6;
   else if st_dom in ("AR", "LA", "OK", "TX") then region=7;
   else if st_dom in ("AZ", "CO", "ID", "MT", "NV", "NM", "UT", "WY") then region=8;
   else if st_dom in ("AK", "CA", "HI", "OR", "WA") then region=9;

   hours=(hours_temp*12)/(full+partial);

   length ltmob active3 3;

   active3=ea1>0 and ea2>0 and ea3>0;

   eda13=0;
   if ea1>0 or ea3>0 then eda13=(ea3-ea1)/((ea1+ea3)/2);
   ltmob=0;
   if active3=1 then do;
      if  eda13<-&cut_ltm then ltmob=1;
      else if eda13>=-&cut_ltm and eda13<=&cut_ltm then ltmob=2;
      else if eda13>&cut_ltm then ltmob=3;
   end;

   if active3=0 then eda13_0=eda13;
   if active3=1 then eda13_1=eda13;

   if qcat="00 " then ltmob=0;
run;

proc contents data=temp1;
run;

proc summary data=temp1 nway;
   class pchar qcat;
   output out=dot.qc_pchar_means(drop=_TYPE_ _FREQ_) n(_NUMERIC_)= mean(_NUMERIC_)= /autoname;
run;
proc contents data=dot.qc_pchar_means;
proc print data=dot.qc_pchar_means;
run;

proc freq data=temp1 noprint;
   tables pchar*qcat*ltmob /missing out=dot.qc_pchar_ltmob(drop=PERCENT); 
   tables pchar*qcat*region /missing out=dot.qc_pchar_region(drop=PERCENT);
   tables pchar*qcat*ind_dom /missing out=dot.qc_pchar_ind_dom(drop=PERCENT);
   tables pchar*qcat*educ_c /missing out=dot.qc_pchar_educ_c(drop=PERCENT);
run;

proc contents data=dot.qc_pchar_ltmob;
proc print data=dot.qc_pchar_ltmob;
run;
proc contents data=dot.qc_pchar_region;
proc print data=dot.qc_pchar_region;
run;
proc contents data=dot.qc_pchar_ind_dom;
proc print data=dot.qc_pchar_ind_dom;
run;
proc contents data=dot.qc_pchar_educ_c;
proc print data=dot.qc_pchar_educ_c;
run;


*** Earnings Statstics at Common Quantiles ***;

proc univariate data=outputs.pik_vars_2 noprint;
   var earn_all;
   output out=dot.all_quant pctlpre=P_ pctlpts=9 11 24 26 49 51 74 76 89 91;
run;

proc contents data=dot.all_quant;
proc print data=dot.all_quant;
run;

data temp1(keep=pchar qcat earn_all active3 eda13_0 eda13_1 ediff_v first_age hours full partial inactive theta psi_pik ltmob region ind_dom educ_c);
   set outputs.pik_vars_2(keep=pchar earn_all ea1 ea2 ea3 ediff_m ediff_v theta psi_pik hours full partial inactive st_dom ind_dom first_age educ_c rename=(hours=hours_temp));

   length qcat $2;

   array qt{1:10} _TEMPORARY_;

   if _N_=1 then do;
         set dot.all_quant;
         qt{1}=P_9;
         qt{2}=P_11;
         qt{3}=P_24;
         qt{4}=P_26;
         qt{5}=P_49;
         qt{6}=P_51;
         qt{7}=P_74;
         qt{8}=P_76;
         qt{9}=P_89;
         qt{10}=P_91;
   end;

   qcat="00";
   if earn_all>qt{1} and earn_all<=qt{2} then qcat="10";
   else if earn_all>qt{3} and earn_all<=qt{4} then qcat="25";
   else if earn_all>qt{5} and earn_all<=qt{6} then qcat="50";
   else if earn_all>qt{7} and earn_all<=qt{8} then qcat="75";
   else if earn_all>qt{9} and earn_all<=qt{10} then qcat="90";

   length region 3;

   if st_dom in ("CT", "ME", "MA", "NH", "RI", "VT") then region=1;
   else if st_dom in ("NJ", "NY", "PA") then region=2;
   else if st_dom in ("IL", "IN","MI", "OH", "WI") then region=3;
   else if st_dom in ("IA", "KS", "MN", "MO", "NE", "ND", "SD") then region=4;
   else if st_dom in ("DE", "FL", "GA", "MD", "NC", "SC", "VA", "DC", "WV") then region=5;
   else if st_dom in ("AL", "KY", "MS", "TN") then region=6;
   else if st_dom in ("AR", "LA", "OK", "TX") then region=7;
   else if st_dom in ("AZ", "CO", "ID", "MT", "NV", "NM", "UT", "WY") then region=8;
   else if st_dom in ("AK", "CA", "HI", "OR", "WA") then region=9;

   hours=(hours_temp*12)/(full+partial);

   length ltmob active3 3;

   active3=ea1>0 and ea2>0 and ea3>0;

   eda13=0;
   if ea1>0 or ea3>0 then eda13=(ea3-ea1)/((ea1+ea3)/2);
   ltmob=0;
   if active3=1 then do;
      if  eda13<-&cut_ltm then ltmob=1;
      else if eda13>=-&cut_ltm and eda13<=&cut_ltm then ltmob=2;
      else if eda13>&cut_ltm then ltmob=3;
   end;

   if active3=0 then eda13_0=eda13;
   if active3=1 then eda13_1=eda13;

   if qcat="00 " then ltmob=0;
run;

proc contents data=temp1;
run;

proc summary data=temp1 nway;
   class pchar qcat;
   output out=dot.qc_all_means(drop=_TYPE_ _FREQ_) n(_NUMERIC_)= mean(_NUMERIC_)= /autoname;
run;
proc contents data=dot.qc_all_means;
proc print data=dot.qc_all_means;
run;

proc freq data=temp1 noprint;
   tables pchar*qcat*ltmob /missing out=dot.qc_all_ltmob(drop=PERCENT);
   tables pchar*qcat*region /missing out=dot.qc_all_region(drop=PERCENT);
   tables pchar*qcat*ind_dom /missing out=dot.qc_all_ind_dom(drop=PERCENT);
   tables pchar*qcat*educ_c /missing out=dot.qc_all_educ_c(drop=PERCENT);
run;

proc contents data=dot.qc_all_ltmob;
proc print data=dot.qc_all_ltmob;
run;
proc contents data=dot.qc_all_region;
proc print data=dot.qc_all_region;
run;
proc contents data=dot.qc_all_ind_dom;
proc print data=dot.qc_all_ind_dom;
run;
proc contents data=dot.qc_all_educ_c;
proc print data=dot.qc_all_educ_c;
run;
