*** Create Region Industry and Education Variables ***;

%include "../config.sas";

*** Region ***;

proc sort data=dot.qc_pchar_region out=temp1;
   by pchar qcat descending COUNT;
run;

proc summary data=dot.qc_pchar_region nway;
   class pchar qcat;
   output out=temp2(drop=_TYPE_ _FREQ_) sum(COUNT)=N;
run;

data temp3r(keep=pchar qcat reg_CN reg1_N reg2_N reg1 reg2 regS);
   merge temp1 temp2;
      by pchar qcat;

   retain i reg_CN  reg1_N reg2_N reg1 reg2 regS;
   
   if first.qcat then do;
      i=0;
      reg_CN=0;
      reg1=.;
      reg2=.;
      regS=0;
   end;

   i=i+1;
   if i<=2 then do;
      if i=1 then do;
         reg1_N=COUNT;
         reg1=region;
      end;
      if i=2 then do;
         reg2_N=COUNT;
         reg2=region;
      end;
      share=COUNT/N;
      regS=regS+share;
   end;
   else do;
      reg_CN=reg_CN+COUNT;
   end;

   if last.qcat then output;
run;

proc contents data=temp3r;
proc means data=temp3r;
run;
proc print data=temp3r;
run;

*** Industry ***;

proc sort data=dot.qc_pchar_ind_dom out=temp1;
   by pchar qcat descending COUNT;
run;

proc summary data=dot.qc_pchar_ind_dom nway;
   class pchar qcat;
   output out=temp2(drop=_TYPE_ _FREQ_) sum(COUNT)=N;
run;

data temp3i(keep=pchar qcat ind_CN ind1_N ind2_N ind3_N ind4_N ind1 ind2 ind3 ind4 indS);
   merge temp1 temp2;
      by pchar qcat;

   retain i ind_CN ind1_N ind2_N ind3_N ind4_N ind1 ind2 ind3 ind4 indS;

   length ind1 ind2 ind3 ind4 $1;

   if first.qcat then do;
      i=0;
      ind_CN=0;
      ind1=" ";
      ind2=" ";
      ind3=" ";
      ind4=" ";
      indS=0;
   end;

   i=i+1;
   if i<=4 then do;
      if i=1 then do;
         ind1_N=COUNT;
         ind1=ind_dom;
      end;
      if i=2 then do;
         ind2_N=COUNT;
         ind2=ind_dom;
      end;
      if i=3 then do;
         ind3_N=COUNT;
         ind3=ind_dom;
      end;
      if i=4 then do;
         ind4_N=COUNT;
         ind4=ind_dom;
      end;
      share=COUNT/N;
      indS=indS+share;
   end;
   else do;
      ind_CN=ind_CN+COUNT;
   end;

   if last.qcat then output;
run;

proc contents data=temp3i;
proc means data=temp3i;
run;
proc print data=temp3i;
run;

*** Education ***;

proc summary data=dot.qc_pchar_educ_c nway;
   class pchar qcat;
   output out=temp2(drop=_TYPE_ _FREQ_) sum(COUNT)=N;
run;

data temp3e(keep=pchar qcat edu_CN edu1_N edu4_N edu1 edu4);
   merge dot.qc_pchar_educ_c temp2;
      by pchar qcat;

   retain edu_CN edu1_N edu4_N edu1 edu4;

   if first.qcat then do;
      edu_CN=0;
      edu1_N=0;
      edu4_N=0;
      edu1=0;
      edu4=0;
   end;

   if educ_c="1" then do;
      edu1_N=COUNT;
      edu1=COUNT/N;
   end;
   if educ_c="2" or educ_c="3" then do;
      edu_CN=edu_CN+COUNT;
   end;
   if educ_c="4" then do;
      edu4_N=COUNT;
      edu4=COUNT/N;
   end;

   if last.qcat then output;
run;

proc contents data=temp3e;
proc means data=temp3e;
run;
proc print data=temp3e;
run;
   
*** Put Everything Together ***;

data dot.qc_pchar_means_2;
   merge dot.qc_pchar_means temp3r temp3i temp3e;
      by pchar qcat;

run;

proc contents data=dot.qc_pchar_means_2;
proc print data=dot.qc_pchar_means_2;
run;
