*** Round All Statistics to Four Significant Digits ***;

%include "../config.sas";

options ps=32767;

%let sigfig=4;

%macro drb;
   data dlist1(drop=i vlist);
      set &fname;

      array numv{*} _NUMERIC_;

      /* en.wikipedia.org/wiki/Significant_figures */;

      /* Formula
         x = input variable
         p = number of significant digits to retain for input variable x
         v = output variable
         n = floor(log10(x))+1-p
         v = round(x*10**-n)*10**n
      */;

      array parm{3} _TEMPORARY_;

      do i=1 to dim(numv);
         vlist=numv{i};

         if vlist=. or vlist=0 then parm{1}=0;
         else if vlist>0 then parm{1}=1;
         else if vlist<0 then parm{1}=2;

         if parm{1}=1 then do;
            parm{3}=vlist;
            parm{2}=floor(log10(parm{3}))+1-&sigfig;
            vlist=(round(parm{3}*10**-parm{2})*10**parm{2});
         end;
         else if parm{1}=2 then do;
            parm{3}=abs(vlist);
            parm{2}=floor(log10(parm{3}))+1-&sigfig;
            vlist=-(round(parm{3}*10**-parm{2})*10**parm{2});
         end;
         numv{i}=vlist;
      end;
   run;

   title1 "################################################################################ ";
   title2 "### Listing [&list.] Sample [&samp.] # Variable [&var.] # Program [&prog.] # Result File [&fname.] ###";
   proc print data=dlist1;
   run;
%mend;


*** Disclosure List 1 ****;
data ea_pchar;
   retain pchar qcat N earn_all_Mean active3_Mean eda13_0_Mean eda13_1_Mean ediff_v_Mean hours_Mean partial_Mean inactive_Mean theta_Mean psi_pik_Mean;
   set dot.qc_pchar_means_2(keep=pchar qcat earn_all_N earn_all_Mean active3_Mean eda13_0_Mean eda13_1_Mean ediff_v_Mean
                                 hours_Mean partial_Mean inactive_Mean theta_Mean psi_pik_Mean rename=(earn_all_N=N));

   if N<15 then N=0;
   else if N>=15 and N<100 then N=round(N,10);
   else if N>=100 and N<1000 then N=round(N,50);
   else if N>=1000 and N<10000 then N=round(N,100);
   else if N>=10000 and N<100000 then N=round(N,500);
   else if N>=100000 and N<1000000 then N=round(N,1000);
run;
/* List:        */; %let list  = 1;
/* Sample:      */; %let samp  = 1 : Persons : Earnings and Hours Worked Measures by PCHAR Earnings Bin;
/* Variable:    */; %let var   = See list;
/* Program:     */; %let prog  = 09.01.earn_vars.sas;
/* Result File: */; %let fname = ea_pchar;
%drb;

*** Disclosure List 2 ****;
data disc1;
   retain pchar qcat earn_all_N active3_N eda13_0_N eda13_1_N ediff_v_N hours_N full_N partial_N inactive_N theta_N psi_pik_N;
   set dot.qc_pchar_means_2(keep=pchar qcat earn_all_N active3_N  eda13_0_N eda13_1_N ediff_v_N hours_N full_N partial_N inactive_N theta_N psi_pik_N);;
run;
proc contents data=disc1;
proc print data=disc1;
run;

*** Disclosure List 3 ****;
data ea_pchar;
   retain pchar qcat reg1 reg2 regS ind1 ind2 ind3 ind4 indS first_age_Mean edu1 edu4;
   set dot.qc_pchar_means_2(keep=pchar qcat reg1 reg2 regS ind1 ind2 ind3 ind4 indS first_age_Mean edu1 edu4);
run;
/* List:        */; %let list  = 3;
/* Sample:      */; %let samp  = 1 : Persons : Person and Firm Characteristics by PCHAR Earnings Bin;
/* Variable:    */; %let var   = See list;
/* Program:     */; %let prog  = 09.01.earn_vars.sas 10.01.reg_ind_edu_pchar.sas;
/* Result File: */; %let fname = ea_pchar;
%drb;

*** Disclosure List 4 ****;
data disc3;
   retain pchar qcat reg_CN reg1_N reg2_N ind_CN ind1_N ind2_N ind3_N ind4_N first_age_N edu_CN edu1_N edu4_N;
   set dot.qc_pchar_means_2(keep=pchar qcat reg_CN reg1_N reg2_N ind_CN ind1_N ind2_N ind3_N ind4_N first_age_N edu_CN edu1_N edu4_N);
run;
proc contents data=disc3;
proc print data=disc3;
run;

*** Disclosure List 5 ****;
data ea_pchar;
   retain pchar qcat N earn_all_Mean active3_Mean eda13_0_Mean eda13_1_Mean ediff_v_Mean hours_Mean partial_Mean inactive_Mean theta_Mean psi_pik_Mean;
   set dot.qc_all_means_2(keep=pchar qcat earn_all_N earn_all_Mean active3_Mean eda13_0_Mean eda13_1_Mean ediff_v_Mean
                                 hours_Mean partial_Mean inactive_Mean theta_Mean psi_pik_Mean rename=(earn_all_N=N));

   if N<15 then N=0;
   else if N>=15 and N<100 then N=round(N,10);
   else if N>=100 and N<1000 then N=round(N,50);
   else if N>=1000 and N<10000 then N=round(N,100);
   else if N>=10000 and N<100000 then N=round(N,500);
   else if N>=100000 and N<1000000 then N=round(N,1000);
run;
/* List:        */; %let list  = 5;
/* Sample:      */; %let samp  = 1 : Persons : Earnings and Hours Worked Measures by ALL Worker Earnings Bin;
/* Variable:    */; %let var   = See list;
/* Program:     */; %let prog  = 09.01.earn_vars.sas;
/* Result File: */; %let fname = ea_pchar;
%drb;

*** Disclosure List 6 ****;
data disc5;
   retain pchar qcat earn_all_N active3_N eda13_0_N eda13_1_N ediff_v_N hours_N full_N partial_N inactive_N theta_N psi_pik_N;
   set dot.qc_all_means_2(keep=pchar qcat earn_all_N active3_N eda13_0_N eda13_1_N ediff_v_N hours_N full_N partial_N inactive_N theta_N psi_pik_N);;
run;
proc contents data=disc5;
proc print data=disc5;
run;

*** Disclosure List 7 ****;
data ea_pchar;
   retain pchar qcat reg1 reg2 regS ind1 ind2 ind3 ind4 indS first_age_Mean edu1 edu4;
   set dot.qc_all_means_2(keep=pchar qcat reg1 reg2 regS ind1 ind2 ind3 ind4 indS first_age_Mean edu1 edu4);
run;
/* List:        */; %let list  = 7;
/* Sample:      */; %let samp  = 1 : Persons : Person and Firm Characteristics by ALL Worker Earnings Bin;
/* Variable:    */; %let var   = See list;
/* Program:     */; %let prog  = 09.01.earn_vars.sas 10.02.reg_ind_edu_all.sas;
/* Result File: */; %let fname = ea_pchar;
%drb;

*** Disclosure List 8 ****;
data disc7;
   retain pchar qcat reg_CN reg1_N reg2_N ind_CN ind1_N ind2_N ind3_N ind4_N first_age_N edu_CN edu1_N edu4_N;
   set dot.qc_all_means_2(keep=pchar qcat reg_CN reg1_N reg2_N ind_CN ind1_N ind2_N ind3_N ind4_N first_age_N edu_CN edu1_N edu4_N);
run;
proc contents data=disc7;
proc print data=disc7;
run;
