*** Get Information on and Select the Analysis Sample ***;

%include "../config.sas";
%include "../00_macros/pik2short.sas";
%include "../00_macros/sline.sas";


data temp0 /view=temp0;
   %sline(lib=outputs,data=iv_work,keepvars=_ALL_);
run;

data outputs.pik_year_vars(drop=full partial inactive ftspells last_wrk earn_all check wrk_hist log_earn_all)
     outputs.pik_vars(keep=pik age_cohort born_US ethnicity first_age first_year in_sample last_year pchar race sex slength work_ever
                           full partial inactive earn_all log_earn_all ftspells wrk_hist);

   set temp0;
      by pik;

   retain full partial inactive ftspells last_wrk earn_all;

   length active full partial inactive ftspells last_wrk 3;

   if first.pik then do;
      full=0;
      partial=0;
      inactive=0;
      if wrk4all=0 then ftspells=0;
      else ftspells=1;
      earn_all=0;
   end;

   active=earn_pce>0;

   if active=1 then log_earn_pce=log(earn_pce);

   if wrk4all=1 then full=full+1;
   else if wrk4all=0 and earn_pce>0 then partial=partial+1;
   else inactive=inactive+1;

   earn_all=earn_all+earn_pce;

   if not(first.pik) then do;
      if last_wrk=0 and wrk4all=1 then ftspells=ftspells+1;
   end;

   last_wrk=wrk4all;

   if last.pik then do;
      check=full+partial+inactive;
      if (inactive=0 and full=12) then wrk_hist=4;
      else if (inactive=0 and full<12) or (inactive=1 and full>=7) or
         (inactive=2 and full>=7) then wrk_hist=3;
      else if (inactive>=8) or (inactive=7 and full<=3) or
              (inactive=6 and full<=2) then wrk_hist=1;
      else wrk_hist=2;
      earn_all=earn_all/12;
      if earn_all>0 then log_earn_all=log(earn_all);
      output outputs.pik_vars;
   end;

   output outputs.pik_year_vars;
run;

*** Person Statistics ***;
proc contents data=outputs.pik_vars;
proc freq data=outputs.pik_vars;
   tables work_ever /out=cut0;
run;
proc freq data=outputs.pik_vars(where=(first_year=2004));
   tables work_ever /out=cut1;
run;
proc freq data=outputs.pik_vars(where=(first_year=2004 and first_age>=25 and first_age<=54));
   tables work_ever /out=cut2;
run;
proc freq data=outputs.pik_vars(where=(first_year=2004 and first_age>=25 and first_age<=54 and slength=12));
   tables work_ever /out=cut3;
run;
proc freq data=outputs.pik_vars(where=(in_sample=1));
   tables work_ever /out=cut3;
run;

data dot.in_sample;
   merge cut0(keep=work_ever count rename=(count=cut0))
         cut1(keep=work_ever count rename=(count=cut1))
         cut2(keep=work_ever count rename=(count=cut2))
         cut3(keep=work_ever count rename=(count=cut3));
      by work_ever;
run;

proc contents data=dot.in_sample;
proc print data=dot.in_sample;
run;

proc summary data=outputs.pik_vars(where=(in_sample=1));
   class wrk_hist;
   output out=dot.learn_all mean(log_earn_all)=mean_learn_all std(log_earn_all)=std_learn_all;
run;
proc contents data=dot.learn_all;
proc print data=dot.learn_all;
run;

proc print data=outputs.pik_vars(obs=100);
run;


*** Person Year Statistics ***;
proc contents data=outputs.pik_year_vars;
proc freq data=outputs.pik_year_vars;
   tables year*work_ever /out=cut0;
run;
proc transpose data=cut0 out=cut0w prefix=work_ever_;
   by year;
   id work_ever;
   var count;
run;
proc print data=cut0w;
run;
proc freq data=outputs.pik_year_vars(where=(work_ever=1));
   tables year*in_sample /out=cut1;
run;
proc transpose data=cut1 out=cut1w prefix=in_sample_;
   by year;
   id in_sample;
   var count;
run;
proc print data=cut1w;
run;
proc freq data=outputs.pik_year_vars(where=(in_sample=1));
   tables year*active /out=cut2;
run;
proc transpose data=cut2 out=cut2w prefix=active_;
   by year;
   id active;
   var count;
run;
proc print data=cut2w;
run;

data dot.in_sample_year;
   merge cut0w(drop=_NAME_ _LABEL_)
         cut1w(drop=_NAME_ _LABEL_)
         cut2w(drop=_NAME_ _LABEL_);
      by year;
run;

proc contents data=dot.in_sample_year;
proc print data=dot.in_sample_year;
run;

proc summary data=outputs.pik_year_vars(where=(in_sample=1 and active=1));
   class year;
   output out=dot.learn_pce mean(log_earn_pce)=mean_learn_pce std(log_earn_pce)=std_learn_pce;
run;
proc contents data=dot.learn_pce;
proc print data=dot.learn_pce;
run;

proc freq data=outputs.pik_year_vars(where=(in_sample=1));
   tables age_cohort*year*active /out=cut0;
run;
proc transpose data=cut0 out=dot.ac_active(drop=_NAME_ _LABEL_) prefix=active_;
   by age_cohort year;
   id active;
   var count;
run;
proc contents data=dot.ac_active;
proc print data=dot.ac_active;
run;

proc summary data=outputs.pik_year_vars(where=(in_sample=1 and active=1)) nway;
   class age_cohort year;
   output out=dot.ac_learn_pce(drop=_TYPE_) mean(log_earn_pce)=mean_learn_pce std(log_earn_pce)=std_learn_pce;
run;
proc contents data=dot.ac_learn_pce;
proc print data=dot.ac_learn_pce;
run;

proc print data=outputs.pik_year_vars(obs=100);
run;
