*** Quantile Regression ***;

%include "../config.sas";


data temp0(keep=pchar earn_all log_earn_all hours hours2 hours3 hours4 partial inactive region ind_dom first_age educ_c theta psi_pik);
   set outputs.pik_vars_2(rename=(hours=hours_temp));

   if st_dom in ("CT", "ME", "MA", "NH", "RI", "VT") then region=1;
   else if st_dom in ("NJ", "NY", "PA") then region=2;
   else if st_dom in ("IL", "IN","MI", "OH", "WI") then region=3;
   else if st_dom in ("IA", "KS", "MN", "MO", "NE", "ND", "SD") then region=4;
   else if st_dom in ("DE", "FL", "GA", "MD", "NC", "SC", "VA", "DC", "WV") then region=5;
   else if st_dom in ("AL", "KY", "MS", "TN") then region=6;
   else if st_dom in ("AR", "LA", "OK", "TX") then region=7;
   else if st_dom in ("AZ", "CO", "ID", "MT", "NV", "NM", "UT", "WY") then region=8;
   else if st_dom in ("AK", "CA", "HI", "OR", "WA") then region=9;

   hours=(hours_temp*12)/(full+partial);

   hours2=(hours**2)/1000;
   hours3=(hours**3)/10000000;
   hours4=(hours**4)/10000000000;

run;

proc means data=temp0 mean p10 p25 median p75 p90;
   class pchar;
   var earn_all log_earn_all;
run;

proc freq data=temp0;
   tables pchar /list missing;
   tables region /list missing;
   tables ind_dom /list missing;
   tables educ_c /list missing;
run;
   
ods output ParameterEstimates=betas_glm_0(keep=Parameter Estimate rename=(Estimate=Estimate0));
proc glm data=temp0;
  class pchar region ind_dom educ_c;
  model log_earn_all=pchar /solution;
quit;
run;
ods output close;
data betas_glm2_0(drop=Parameter rename=(Parameter_New=Parameter));
   set betas_glm_0;

   length Parameter_New $18;

   Parameter_New=put(_N_,z2.) || " " || Parameter;
run;
proc contents data=betas_glm2_0;
proc print data=betas_glm2_0;
run;

ods output ParameterEstimates=betas_glm_1(keep=Parameter Estimate rename=(Estimate=Estimate1));
proc glm data=temp0;
  class pchar region ind_dom educ_c;
  model log_earn_all=pchar hours hours2 hours3 hours4 partial inactive /solution;
quit;
run;
ods output close;
data betas_glm2_1(drop=Parameter rename=(Parameter_New=Parameter));
   set betas_glm_1;

   length Parameter_New $18;

   Parameter_New=put(_N_,z2.) || " " || Parameter;
run;
proc contents data=betas_glm2_1;
proc print data=betas_glm2_1;
run;

ods output ParameterEstimates=betas_glm_2(keep=Parameter Estimate rename=(Estimate=Estimate2));
proc glm data=temp0;
  class pchar region ind_dom educ_c;
  model log_earn_all=pchar hours hours2 hours3 hours4 partial inactive region ind_dom /solution;
quit;
run;
ods output close;
data betas_glm2_2(drop=Parameter rename=(Parameter_New=Parameter));
   set betas_glm_2;

   length Parameter_New $18;

   Parameter_New=put(_N_,z2.) || " " || Parameter;
run;
proc contents data=betas_glm2_2;
proc print data=betas_glm2_2;
run;

ods output ParameterEstimates=betas_glm_3(keep=Parameter Estimate rename=(Estimate=Estimate3));
proc glm data=temp0;
  class pchar region ind_dom educ_c;
  model log_earn_all=pchar hours hours2 hours3 hours4 partial inactive region ind_dom first_age educ_c /solution;
quit;
run;
ods output close;
data betas_glm2_3(drop=Parameter rename=(Parameter_New=Parameter));
   set betas_glm_3;

   length Parameter_New $18;

   Parameter_New=put(_N_,z2.) || " " || Parameter;
run;
proc contents data=betas_glm2_3;
proc print data=betas_glm2_3;
run;

ods output ParameterEstimates=betas_glm_4(keep=Dependent Parameter Estimate rename=(Estimate=Estimate4));
proc glm data=temp0;
  class pchar region ind_dom educ_c;
  model log_earn_all=pchar hours hours2 hours3 hours4 partial inactive region ind_dom first_age theta psi_pik /solution;
quit;
run;
ods output close;
data betas_glm2_4(drop=Parameter rename=(Parameter_New=Parameter));
   set betas_glm_4;

   length Parameter_New $18;

   Parameter_New=put(_N_,z2.) || " " || Parameter;
run;
proc contents data=betas_glm2_4;
proc print data=betas_glm2_4;
run;

data dot.glm_betas_02;
   retain Dependent Parameter;
   merge betas_glm2_0 betas_glm2_1 betas_glm2_2 betas_glm2_3 betas_glm2_4;
      by Parameter;
run;

proc contents data=dot.glm_betas_02;
proc print data=dot.glm_betas_02;
run;
