*** Round All Statistics to Four Significant Digits ***;

%include "../../../config.sas";

options ps=32767;

%let sigfig=4;

%macro drb;
   data dlist1(drop=i vlist);
      set &fname;

      array numv{*} _NUMERIC_;

      /* en.wikipedia.org/wiki/Significant_figures */;

      /* Formula
         x = input variable
         p = number of significant digits to retain for input variable x
         v = output variable
         n = floor(log10(x))+1-p
         v = round(x*10**-n)*10**n
      */;

      array parm{3} _TEMPORARY_;

      do i=1 to dim(numv);
         vlist=numv{i};

         if vlist=. or vlist=0 then parm{1}=0;
         else if vlist>0 then parm{1}=1;
         else if vlist<0 then parm{1}=2;

         if parm{1}=1 then do;
            parm{3}=vlist;
            parm{2}=floor(log10(parm{3}))+1-&sigfig;
            vlist=(round(parm{3}*10**-parm{2})*10**parm{2});
         end;
         else if parm{1}=2 then do;
            parm{3}=abs(vlist);
            parm{2}=floor(log10(parm{3}))+1-&sigfig;
            vlist=-(round(parm{3}*10**-parm{2})*10**parm{2});
         end;
         numv{i}=vlist;
      end;
   run;

   title1 "################################################################################ ";
   title2 "### Listing [&list.] Sample [&samp.] # Variable [&var.] # Program [&prog.] # Result File [&fname.] ###";
   proc print data=dlist1;
   run;
%mend;


*** Disclosure List 1 ****;
data ea_pchar;
   set dot.decomprun_avg(keep=pchar1 pchar0 quantile leap_w1x1 leap_w0x0 leap_w0x1 leap_w1x0);
run;
/* List:        */; %let list  = 1;
/* Sample:      */; %let samp  = 1 : Persons : Quantile Earnings Regressions;
/* Variable:    */; %let var   = Earnings Decomposition;
/* Program:     */; %let prog  = 08_decomp_table_avg.sas;
/* Result File: */; %let fname = ea_pchar;
%drb;

endsas;

*** Disclosure List 2 ****;
data ea_pchar;
   retain pchar qcat earn_all_N active3_Mean eda13_0_N eda13_1_N ediff_v_N hours_N full_N partial_N inactive_N theta_N psi_pik_N;
   set dot.qc_pchar_means_2(keep=pchar qcat earn_all_N active3_Mean eda13_0_N eda13_1_N ediff_v_N hours_N full_N partial_N inactive_N theta_N psi_pik_N);;
run;
/* List:        */; %let list  = 1;
/* Sample:      */; %let samp  = 1 : Persons : DA counts for Disclosure List 1;
/* Variable:    */; %let var   = See list;
/* Program:     */; %let prog  = 09.01.earn_vars.sas;
/* Result File: */; %let fname = ea_pchar;
%drb;

*** Disclosure List 3 ****;
data ea_pchar;
   retain pchar qcat reg1 reg2 regS ind1 ind2 ind3 ind4 indS first_age_Mean edu1 edu4;
   set dot.qc_pchar_means_2(keep=pchar qcat reg1 reg2 regS ind1 ind2 ind3 ind4 indS first_age_Mean edu1 edu4);
run;
/* List:        */; %let list  = 2;
/* Sample:      */; %let samp  = 1 : Persons : Person and Firm Characteristics by PCHAR Earnings Bin;
/* Variable:    */; %let var   = See list;
/* Program:     */; %let prog  = 09.01.earn_vars.sas 10.01.reg_ind_edu_pchar.sas;
/* Result File: */; %let fname = ea_pchar;
%drb;


*** Disclosure List 4 ****;
data ea_pchar;
   retain pchar qcat reg_CN reg1_N reg2_N ind_CN ind1_N ind2_N ind3_N ind4_N first_age_N edu_CN edu1_N edu4_N;
   set dot.qc_pchar_means_2(keep=pchar qcat reg_CN reg1_N reg2_N ind_CN ind1_N ind2_N ind3_N ind4_N first_age_N edu_CN edu1_N edu4_N);
run;
/* List:        */; %let list  = 2;
/* Sample:      */; %let samp  = 1 : Persons : Person and Firm Characteristics by PCHAR Earnings Bin;
/* Variable:    */; %let var   = See list;
/* Program:     */; %let prog  = 09.01.earn_vars.sas 10.01.reg_ind_edu_pchar.sas;
/* Result File: */; %let fname = ea_pchar;
%drb;

endsas;

*** Disclosure List 3 ****;
/* List:        */; %let list  = 3;
/* Sample:      */; %let samp  = 1 : Person Years : Sample Selection (Active) ;
/* Variable:    */; %let var   = counts
/* Program:     */; %let prog  = 01.01.earn_var.sas;
/* Result File: */; %let fname = dot.in_sample_year;
%drb;

*** Disclosure List 4 ****;
/* List:        */; %let list  = 4;
/* Sample:      */; %let samp  = 1 : Person Years : Log Total Earnings All Jobs ;
/* Variable:    */; %let var   = log_earn_pce
/* Program:     */; %let prog  = 01.01.earn_var.sas;
/* Result File: */; %let fname = dot.learn_pce;
%drb;

*** Disclosure List 5 ****;
/* List:        */; %let list  = 5;
/* Sample:      */; %let samp  = 1 : Person Years : Active by age_cohort ;
/* Variable:    */; %let var   = counts
/* Program:     */; %let prog  = 01.01.earn_var.sas;
/* Result File: */; %let fname = dot.ac_active;
%drb;

*** Disclosure List 6 ****;
/* List:        */; %let list  = 6;
/* Sample:      */; %let samp  = 1 : Person Years : Log Total Earnings All Jobs by age_cohort ;
/* Variable:    */; %let var   = log_earn_pce
/* Program:     */; %let prog  = 01.01.earn_var.sas;
/* Result File: */; %let fname = dot.ac_learn_pce;
%drb;

*** Disclosure List 7 ****;

/* List:        */; %let list  = 7;
/* Sample:      */; %let samp  = 1 : Persons : Total Earnings All Jobs by Person Chars ;
/* Variable:    */; %let var   = earn_all;
/* Program:     */; %let prog  = 03.01.work_hist_drb.sas;
/* Result File: */; %let fname = ea_pchar;
%drb;

*** Disclosure List 8 ****;
data ea_pc_wh;
   set dot.ea_pc_wh(keep=pchar wrk_hist so_n P_10 P_25 P_50 P_75 P_90 rename=(so_n=N));

   if N<15 then N=0;
   else if N>=15 and N<100 then N=round(N,10);
   else if N>=100 and N<1000 then N=round(N,50);
   else if N>=1000 and N<10000 then N=round(N,100);
   else if N>=10000 and N<100000 then N=round(N,500);
   else if N>=100000 and N<1000000 then N=round(N,1000);
run;

/* List:        */; %let list  = 8;
/* Sample:      */; %let samp  = 1 : Persons : Total Earnings All Jobs by Person Chars and wrk_hist ;
/* Variable:    */; %let var   = earn_all;
/* Program:     */; %let prog  = 03.01.work_hist_drb.sas;
/* Result File: */; %let fname = ea_pc_wh;
%drb;

*** Disclosure List 9 ****;
data ea_pc_ac_wh;
   set dot.ea_pc_ac_wh(keep=pchar age_cohort wrk_hist so_n P_10 P_25 P_50 P_75 P_90 rename=(so_n=N));

   if N<15 then N=0;
   else if N>=15 and N<100 then N=round(N,10);
   else if N>=100 and N<1000 then N=round(N,50);
   else if N>=1000 and N<10000 then N=round(N,100);
   else if N>=10000 and N<100000 then N=round(N,500);
   else if N>=100000 and N<1000000 then N=round(N,1000);
run;

/* List:        */; %let list  = 9;
/* Sample:      */; %let samp  = 1 : Persons : Total Earnings All Jobs by Person Chars Age Cohort and wrk_hist ;
/* Variable:    */; %let var   = earn_all;
/* Program:     */; %let prog  = 03.01.work_hist_drb.sas;
/* Result File: */; %let fname = ea_pc_ac_wh;
%drb;
